from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.details.details_api import DetailsApi
from bitmovin_api_sdk.ai_scene_analysis.analyses.by_encoding_id.details.language.language_api import LanguageApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class InterlaceMode(Enum):
    TOP = "TOP"
    BOTTOM = "BOTTOM"
    DROP_EVEN = "DROP_EVEN"
    DROP_ODD = "DROP_ODD"
    PAD = "PAD"
    INTERLACE_X2 = "INTERLACE_X2"
    MERGE = "MERGE"
    MERGE_X2 = "MERGE_X2"



from bitmovin_api_sdk.encoding.live.standby_pools.logs.logs_api import LogsApi
from bitmovin_api_sdk.encoding.live.standby_pools.logs.live_standby_pool_event_log_list_query_params import LiveStandbyPoolEventLogListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.live_encoding_stats import LiveEncodingStats
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.events.events_api import EventsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.streams.streams_api import StreamsApi
from bitmovin_api_sdk.encoding.statistics.encodings.live_statistics.srt.srt_api import SrtApi


class LiveStatisticsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(LiveStatisticsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.events = EventsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.streams = StreamsApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.srt = SrtApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> LiveEncodingStats
        """List Live Statistics from an Encoding

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :return: Live encoding statistics
        :rtype: LiveEncodingStats
        """

        return self.api_client.get(
            '/encoding/statistics/encodings/{encoding_id}/live-statistics',
            path_params={'encoding_id': encoding_id},
            type=LiveEncodingStats,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.thumbnail_aspect_mode import ThumbnailAspectMode
from bitmovin_api_sdk.models.thumbnail_unit import ThumbnailUnit
import pprint
import six


class Thumbnail(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 height=None,
                 width=None,
                 pattern=None,
                 interval=None,
                 positions=None,
                 outputs=None,
                 unit=None,
                 aspect_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, int, int, string_types, float, list[float], list[EncodingOutput], ThumbnailUnit, ThumbnailAspectMode) -> None
        super(Thumbnail, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._height = None
        self._width = None
        self._pattern = None
        self._interval = None
        self._positions = list()
        self._outputs = list()
        self._unit = None
        self._aspect_mode = None
        self.discriminator = None

        if height is not None:
            self.height = height
        if width is not None:
            self.width = width
        if pattern is not None:
            self.pattern = pattern
        if interval is not None:
            self.interval = interval
        if positions is not None:
            self.positions = positions
        if outputs is not None:
            self.outputs = outputs
        if unit is not None:
            self.unit = unit
        if aspect_mode is not None:
            self.aspect_mode = aspect_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Thumbnail, self), 'openapi_types'):
            types = getattr(super(Thumbnail, self), 'openapi_types')

        types.update({
            'height': 'int',
            'width': 'int',
            'pattern': 'string_types',
            'interval': 'float',
            'positions': 'list[float]',
            'outputs': 'list[EncodingOutput]',
            'unit': 'ThumbnailUnit',
            'aspect_mode': 'ThumbnailAspectMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Thumbnail, self), 'attribute_map'):
            attributes = getattr(super(Thumbnail, self), 'attribute_map')

        attributes.update({
            'height': 'height',
            'width': 'width',
            'pattern': 'pattern',
            'interval': 'interval',
            'positions': 'positions',
            'outputs': 'outputs',
            'unit': 'unit',
            'aspect_mode': 'aspectMode'
        })
        return attributes

    @property
    def height(self):
        # type: () -> int
        """Gets the height of this Thumbnail.

        Height of the thumbnail, either height or width are required fields. If only one is given the encoder will calculate the other way value based on the aspect ratio of the video file. If the encoder version is below 2.83.0 only height is supported and mandatory. 

        :return: The height of this Thumbnail.
        :rtype: int
        """
        return self._height

    @height.setter
    def height(self, height):
        # type: (int) -> None
        """Sets the height of this Thumbnail.

        Height of the thumbnail, either height or width are required fields. If only one is given the encoder will calculate the other way value based on the aspect ratio of the video file. If the encoder version is below 2.83.0 only height is supported and mandatory. 

        :param height: The height of this Thumbnail.
        :type: int
        """

        if height is not None:
            if not isinstance(height, int):
                raise TypeError("Invalid type for `height`, type has to be `int`")

        self._height = height

    @property
    def width(self):
        # type: () -> int
        """Gets the width of this Thumbnail.

        Width of the thumbnail, either height or width are required fields. If only one is given the encoder will calculate the other way value based on the aspect ratio of the video file. If the encoder version is below 2.83.0 only height is supported 

        :return: The width of this Thumbnail.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        # type: (int) -> None
        """Sets the width of this Thumbnail.

        Width of the thumbnail, either height or width are required fields. If only one is given the encoder will calculate the other way value based on the aspect ratio of the video file. If the encoder version is below 2.83.0 only height is supported 

        :param width: The width of this Thumbnail.
        :type: int
        """

        if width is not None:
            if not isinstance(width, int):
                raise TypeError("Invalid type for `width`, type has to be `int`")

        self._width = width

    @property
    def pattern(self):
        # type: () -> string_types
        """Gets the pattern of this Thumbnail.

         Pattern which describes the thumbnail filenames. For example with thumbnail-%number%.png as pattern and 3 positions: thumbnail-3_0.png, thumbnail-5_0.png and thumbnail-25_5.png. (The number represents the position in the source video in seconds, in the previous example the first filename represents the thumbnail at 3s, the second one at 5s and the third one at 25.5s). (required)

        :return: The pattern of this Thumbnail.
        :rtype: string_types
        """
        return self._pattern

    @pattern.setter
    def pattern(self, pattern):
        # type: (string_types) -> None
        """Sets the pattern of this Thumbnail.

         Pattern which describes the thumbnail filenames. For example with thumbnail-%number%.png as pattern and 3 positions: thumbnail-3_0.png, thumbnail-5_0.png and thumbnail-25_5.png. (The number represents the position in the source video in seconds, in the previous example the first filename represents the thumbnail at 3s, the second one at 5s and the third one at 25.5s). (required)

        :param pattern: The pattern of this Thumbnail.
        :type: string_types
        """

        if pattern is not None:
            if not isinstance(pattern, string_types):
                raise TypeError("Invalid type for `pattern`, type has to be `string_types`")

        self._pattern = pattern

    @property
    def interval(self):
        # type: () -> float
        """Gets the interval of this Thumbnail.

        The interval in which to create thumbnails. In seconds (E.g. a value of 4 means create a thumbnail every 4 seconds). Mutually exclusive with positions/unit. Has to be equal to or greater than 1.

        :return: The interval of this Thumbnail.
        :rtype: float
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        # type: (float) -> None
        """Sets the interval of this Thumbnail.

        The interval in which to create thumbnails. In seconds (E.g. a value of 4 means create a thumbnail every 4 seconds). Mutually exclusive with positions/unit. Has to be equal to or greater than 1.

        :param interval: The interval of this Thumbnail.
        :type: float
        """

        if interval is not None:
            if not isinstance(interval, (float, int)):
                raise TypeError("Invalid type for `interval`, type has to be `float`")

        self._interval = interval

    @property
    def positions(self):
        # type: () -> list[float]
        """Gets the positions of this Thumbnail.

        Position in the unit where the thumbnail should be created from. Mutually exclusive with interval.

        :return: The positions of this Thumbnail.
        :rtype: list[float]
        """
        return self._positions

    @positions.setter
    def positions(self, positions):
        # type: (list) -> None
        """Sets the positions of this Thumbnail.

        Position in the unit where the thumbnail should be created from. Mutually exclusive with interval.

        :param positions: The positions of this Thumbnail.
        :type: list[float]
        """

        if positions is not None:
            if not isinstance(positions, list):
                raise TypeError("Invalid type for `positions`, type has to be `list[float]`")

        self._positions = positions

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this Thumbnail.


        :return: The outputs of this Thumbnail.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this Thumbnail.


        :param outputs: The outputs of this Thumbnail.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def unit(self):
        # type: () -> ThumbnailUnit
        """Gets the unit of this Thumbnail.

        Unit of the values in the positions array.

        :return: The unit of this Thumbnail.
        :rtype: ThumbnailUnit
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        # type: (ThumbnailUnit) -> None
        """Sets the unit of this Thumbnail.

        Unit of the values in the positions array.

        :param unit: The unit of this Thumbnail.
        :type: ThumbnailUnit
        """

        if unit is not None:
            if not isinstance(unit, ThumbnailUnit):
                raise TypeError("Invalid type for `unit`, type has to be `ThumbnailUnit`")

        self._unit = unit

    @property
    def aspect_mode(self):
        # type: () -> ThumbnailAspectMode
        """Gets the aspect_mode of this Thumbnail.

        Specifies the aspect mode that is used when both height and width are specified Only supported starting with encoder version `2.85.0`. 

        :return: The aspect_mode of this Thumbnail.
        :rtype: ThumbnailAspectMode
        """
        return self._aspect_mode

    @aspect_mode.setter
    def aspect_mode(self, aspect_mode):
        # type: (ThumbnailAspectMode) -> None
        """Sets the aspect_mode of this Thumbnail.

        Specifies the aspect mode that is used when both height and width are specified Only supported starting with encoder version `2.85.0`. 

        :param aspect_mode: The aspect_mode of this Thumbnail.
        :type: ThumbnailAspectMode
        """

        if aspect_mode is not None:
            if not isinstance(aspect_mode, ThumbnailAspectMode):
                raise TypeError("Invalid type for `aspect_mode`, type has to be `ThumbnailAspectMode`")

        self._aspect_mode = aspect_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Thumbnail, self), "to_dict"):
            result = super(Thumbnail, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Thumbnail):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



import re
from enum import EnumMeta
from importlib import import_module
from dateutil.parser import parse


from bitmovin_api_sdk.models import PaginationResponse


class BitmovinJsonDecoder(object):
    model_module = import_module('bitmovin_api_sdk.models')

    @staticmethod
    def map_dict_to_pagination_response(result, model):
        # type: (object, type) -> object

        model_to_return = BitmovinJsonDecoder.map_dict_to_model(result, PaginationResponse)

        pagination_items = list()

        model_instance = model()
        if 'discriminator_value_class_map' in model.__dict__:
            for i in model_to_return.items:
                model_class = type(model_instance)
                discriminator_value = model_instance.discriminator_value_class_map.get(i['type'])
                if discriminator_value is not None:
                    model_class = getattr(BitmovinJsonDecoder.model_module, discriminator_value)
                pagination_items.append(BitmovinJsonDecoder.map_dict_to_model(i, model_class))
        else:
            pagination_items = BitmovinJsonDecoder.map_dict_to_list(model_to_return.items, model)

        model_to_return.items = pagination_items
        return model_to_return

    @staticmethod
    def map_dict_to_list(result, model):
        # type: (iter, type) -> list

        list_to_return = list()
        for i in result:
            list_to_return.append(BitmovinJsonDecoder.map_dict_to_model(i, model))

        return list_to_return

    @staticmethod
    def map_dict_to_model(result, model):
        # type: (dict, type) -> object

        if isinstance(model, EnumMeta):
            return get_enum_value(result, model)

        if issubclass(model, list):
            return result

        model_instance = model()

        if 'discriminator_value_class_map' in model.__dict__:
            model_name = model_instance.discriminator_value_class_map.get(result['type'])
            if model_name is not None:
                model = getattr(BitmovinJsonDecoder.model_module, model_name)

        model_instance = model()

        if not hasattr(model_instance, 'attribute_map'):
            model_instance.attribute_map = {}

        all_attributes = model_instance.attribute_map

        for key in all_attributes:
            value = result.get(all_attributes.get(key))
            if value is not None:
                type_ = model_instance.openapi_types.get(key)

                try:
                    if re.match('list', type_, re.I):
                        matches = re.search(r'\[(.*)\]', type_)

                        if matches is not None and len(matches.groups()) is 1:
                            if getattr(BitmovinJsonDecoder.model_module, matches.group(1)):
                                model_class = getattr(BitmovinJsonDecoder.model_module,
                                                      matches.group(1))
                                new_value = list()
                                for k in value:
                                    val = k
                                    if isinstance(value, dict):
                                        val = value[k]

                                    new_value.append(
                                        BitmovinJsonDecoder.map_dict_to_model(val, model_class))
                                model_instance.__setattr__(key, new_value)
                                continue

                    model_class = getattr(BitmovinJsonDecoder.model_module, type_)

                    if isinstance(model_class, EnumMeta):
                        value = get_enum_value(value, model_class)
                        model_instance.__setattr__(key, value)
                        continue

                    new_value = BitmovinJsonDecoder.map_dict_to_model(value, model_class)
                    model_instance.__setattr__(key, new_value)
                except (NameError, AttributeError) as e:  # pylint: disable=unused-variable
                    # No model type that has to be special handled
                    if type_ == 'date':
                        new_value = parse(value).date()
                        model_instance.__setattr__(key, new_value)
                    elif type_ == 'datetime':
                        new_value = parse(value)
                        model_instance.__setattr__(key, new_value)
                    else:
                        new_value = value
                        model_instance.__setattr__(key, new_value)

        return model_instance


def get_enum_value(value, model_class):
    # type: (object, EnumMeta) -> str

    # Search for the attribute in the Enum
    for attr in model_class:
        if attr.value == value:
            return attr



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamKeyConfigurationType(Enum):
    GENERATE = "GENERATE"
    ASSIGN = "ASSIGN"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EgressCategory(Enum):
    TRANSFER_RETRY = "TRANSFER_RETRY"
    TRANSFER = "TRANSFER"



from bitmovin_api_sdk.encoding.filters.rotate.rotate_api import RotateApi
from bitmovin_api_sdk.encoding.filters.rotate.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.rotate.rotate_filter_list_query_params import RotateFilterListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.encoding_output_paths import EncodingOutputPaths
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError


class OutputPathsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(OutputPathsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def get(self, encoding_id, **kwargs):
        # type: (string_types, dict) -> list[EncodingOutputPaths]
        """Encoding Output Paths Retrieval

        :param encoding_id: Id of the encoding
        :type encoding_id: string_types, required
        :return: List of output paths per defined encoding output
        :rtype: list[EncodingOutputPaths]
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/output-paths',
            path_params={'encoding_id': encoding_id},
            list_response=True,
            type=EncodingOutputPaths,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
import pprint
import six


class Muxing(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode) -> None
        super(Muxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._streams = list()
        self._outputs = list()
        self._avg_bitrate = None
        self._min_bitrate = None
        self._max_bitrate = None
        self._ignored_by = list()
        self._stream_conditions_mode = None
        self.discriminator = 'type'

        if streams is not None:
            self.streams = streams
        if outputs is not None:
            self.outputs = outputs
        if avg_bitrate is not None:
            self.avg_bitrate = avg_bitrate
        if min_bitrate is not None:
            self.min_bitrate = min_bitrate
        if max_bitrate is not None:
            self.max_bitrate = max_bitrate
        if ignored_by is not None:
            self.ignored_by = ignored_by
        if stream_conditions_mode is not None:
            self.stream_conditions_mode = stream_conditions_mode

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Muxing, self), 'openapi_types'):
            types = getattr(super(Muxing, self), 'openapi_types')

        types.update({
            'streams': 'list[MuxingStream]',
            'outputs': 'list[EncodingOutput]',
            'avg_bitrate': 'int',
            'min_bitrate': 'int',
            'max_bitrate': 'int',
            'ignored_by': 'list[Ignoring]',
            'stream_conditions_mode': 'StreamConditionsMode'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Muxing, self), 'attribute_map'):
            attributes = getattr(super(Muxing, self), 'attribute_map')

        attributes.update({
            'streams': 'streams',
            'outputs': 'outputs',
            'avg_bitrate': 'avgBitrate',
            'min_bitrate': 'minBitrate',
            'max_bitrate': 'maxBitrate',
            'ignored_by': 'ignoredBy',
            'stream_conditions_mode': 'streamConditionsMode'
        })
        return attributes

    discriminator_value_class_map = {
        'FMP4': 'Fmp4Muxing',
        'CMAF': 'CmafMuxing',
        'MP4': 'Mp4Muxing',
        'TS': 'TsMuxing',
        'WEBM': 'WebmMuxing',
        'MP3': 'Mp3Muxing',
        'MXF': 'MxfMuxing',
        'PROGRESSIVE_WAV': 'ProgressiveWavMuxing',
        'PROGRESSIVE_WEBM': 'ProgressiveWebmMuxing',
        'PROGRESSIVE_MOV': 'ProgressiveMovMuxing',
        'PROGRESSIVE_TS': 'ProgressiveTsMuxing',
        'BROADCAST_TS': 'BroadcastTsMuxing',
        'CHUNKED_TEXT': 'ChunkedTextMuxing',
        'TEXT': 'TextMuxing',
        'SEGMENTED_RAW': 'SegmentedRawMuxing',
        'PACKED_AUDIO': 'PackedAudioMuxing'
    }

    @property
    def streams(self):
        # type: () -> list[MuxingStream]
        """Gets the streams of this Muxing.


        :return: The streams of this Muxing.
        :rtype: list[MuxingStream]
        """
        return self._streams

    @streams.setter
    def streams(self, streams):
        # type: (list) -> None
        """Sets the streams of this Muxing.


        :param streams: The streams of this Muxing.
        :type: list[MuxingStream]
        """

        if streams is not None:
            if not isinstance(streams, list):
                raise TypeError("Invalid type for `streams`, type has to be `list[MuxingStream]`")

        self._streams = streams

    @property
    def outputs(self):
        # type: () -> list[EncodingOutput]
        """Gets the outputs of this Muxing.


        :return: The outputs of this Muxing.
        :rtype: list[EncodingOutput]
        """
        return self._outputs

    @outputs.setter
    def outputs(self, outputs):
        # type: (list) -> None
        """Sets the outputs of this Muxing.


        :param outputs: The outputs of this Muxing.
        :type: list[EncodingOutput]
        """

        if outputs is not None:
            if not isinstance(outputs, list):
                raise TypeError("Invalid type for `outputs`, type has to be `list[EncodingOutput]`")

        self._outputs = outputs

    @property
    def avg_bitrate(self):
        # type: () -> int
        """Gets the avg_bitrate of this Muxing.

        Average bitrate. Available after encoding finishes.

        :return: The avg_bitrate of this Muxing.
        :rtype: int
        """
        return self._avg_bitrate

    @avg_bitrate.setter
    def avg_bitrate(self, avg_bitrate):
        # type: (int) -> None
        """Sets the avg_bitrate of this Muxing.

        Average bitrate. Available after encoding finishes.

        :param avg_bitrate: The avg_bitrate of this Muxing.
        :type: int
        """

        if avg_bitrate is not None:
            if not isinstance(avg_bitrate, int):
                raise TypeError("Invalid type for `avg_bitrate`, type has to be `int`")

        self._avg_bitrate = avg_bitrate

    @property
    def min_bitrate(self):
        # type: () -> int
        """Gets the min_bitrate of this Muxing.

        Min bitrate. Available after encoding finishes.

        :return: The min_bitrate of this Muxing.
        :rtype: int
        """
        return self._min_bitrate

    @min_bitrate.setter
    def min_bitrate(self, min_bitrate):
        # type: (int) -> None
        """Sets the min_bitrate of this Muxing.

        Min bitrate. Available after encoding finishes.

        :param min_bitrate: The min_bitrate of this Muxing.
        :type: int
        """

        if min_bitrate is not None:
            if not isinstance(min_bitrate, int):
                raise TypeError("Invalid type for `min_bitrate`, type has to be `int`")

        self._min_bitrate = min_bitrate

    @property
    def max_bitrate(self):
        # type: () -> int
        """Gets the max_bitrate of this Muxing.

        Max bitrate. Available after encoding finishes.

        :return: The max_bitrate of this Muxing.
        :rtype: int
        """
        return self._max_bitrate

    @max_bitrate.setter
    def max_bitrate(self, max_bitrate):
        # type: (int) -> None
        """Sets the max_bitrate of this Muxing.

        Max bitrate. Available after encoding finishes.

        :param max_bitrate: The max_bitrate of this Muxing.
        :type: int
        """

        if max_bitrate is not None:
            if not isinstance(max_bitrate, int):
                raise TypeError("Invalid type for `max_bitrate`, type has to be `int`")

        self._max_bitrate = max_bitrate

    @property
    def ignored_by(self):
        # type: () -> list[Ignoring]
        """Gets the ignored_by of this Muxing.

        This read-only property is set during the analysis step of the encoding. If it contains items, the Muxing has been ignored during the encoding process according to its 'streamConditionsMode'

        :return: The ignored_by of this Muxing.
        :rtype: list[Ignoring]
        """
        return self._ignored_by

    @ignored_by.setter
    def ignored_by(self, ignored_by):
        # type: (list) -> None
        """Sets the ignored_by of this Muxing.

        This read-only property is set during the analysis step of the encoding. If it contains items, the Muxing has been ignored during the encoding process according to its 'streamConditionsMode'

        :param ignored_by: The ignored_by of this Muxing.
        :type: list[Ignoring]
        """

        if ignored_by is not None:
            if not isinstance(ignored_by, list):
                raise TypeError("Invalid type for `ignored_by`, type has to be `list[Ignoring]`")

        self._ignored_by = ignored_by

    @property
    def stream_conditions_mode(self):
        # type: () -> StreamConditionsMode
        """Gets the stream_conditions_mode of this Muxing.

        Specifies how to proceed with the Muxing when some of its Streams are ignored (see 'condition' property of the Stream resource). The settings only make a difference for Muxings with more than one Stream. When retrieving the resource after the analysis step of the encoding has finished, 'ignoredBy' will indicate if and why it has been ignored.

        :return: The stream_conditions_mode of this Muxing.
        :rtype: StreamConditionsMode
        """
        return self._stream_conditions_mode

    @stream_conditions_mode.setter
    def stream_conditions_mode(self, stream_conditions_mode):
        # type: (StreamConditionsMode) -> None
        """Sets the stream_conditions_mode of this Muxing.

        Specifies how to proceed with the Muxing when some of its Streams are ignored (see 'condition' property of the Stream resource). The settings only make a difference for Muxings with more than one Stream. When retrieving the resource after the analysis step of the encoding has finished, 'ignoredBy' will indicate if and why it has been ignored.

        :param stream_conditions_mode: The stream_conditions_mode of this Muxing.
        :type: StreamConditionsMode
        """

        if stream_conditions_mode is not None:
            if not isinstance(stream_conditions_mode, StreamConditionsMode):
                raise TypeError("Invalid type for `stream_conditions_mode`, type has to be `StreamConditionsMode`")

        self._stream_conditions_mode = stream_conditions_mode

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Muxing, self), "to_dict"):
            result = super(Muxing, self).to_dict()
        for k, v in iteritems(self.discriminator_value_class_map):
            if v == type(self).__name__:
                result['type'] = k
                break
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Muxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class DashISO8601TimestampFormat(Enum):
    LONG = "LONG"
    SHORT = "SHORT"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AacChannelLayout(Enum):
    NONE = "NONE"
    MONO = "MONO"
    CL_STEREO = "STEREO"
    CL_SURROUND = "SURROUND"
    CL_4_0 = "4.0"
    CL_5_0_BACK = "5.0_BACK"
    CL_5_1_BACK = "5.1_BACK"
    CL_7_1 = "7.1"
    CL_7_1_WIDE_BACK = "7.1_WIDE_BACK"



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.subtask_metadata_data import SubtaskMetadataData
import pprint
import six


class SubtaskMetadata(object):
    @poscheck_model
    def __init__(self,
                 date_=None,
                 data=None):
        # type: (datetime, SubtaskMetadataData) -> None

        self._date = None
        self._data = None
        self.discriminator = None

        if date_ is not None:
            self.date = date_
        if data is not None:
            self.data = data

    @property
    def openapi_types(self):
        types = {
            'date': 'datetime',
            'data': 'SubtaskMetadataData'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'date': 'date',
            'data': 'data'
        }
        return attributes

    @property
    def date(self):
        # type: () -> datetime
        """Gets the date of this SubtaskMetadata.

        The timestamp of the metadata record (required)

        :return: The date of this SubtaskMetadata.
        :rtype: datetime
        """
        return self._date

    @date.setter
    def date(self, date_):
        # type: (datetime) -> None
        """Sets the date of this SubtaskMetadata.

        The timestamp of the metadata record (required)

        :param date_: The date of this SubtaskMetadata.
        :type: datetime
        """

        if date_ is not None:
            if not isinstance(date_, datetime):
                raise TypeError("Invalid type for `date`, type has to be `datetime`")

        self._date = date_

    @property
    def data(self):
        # type: () -> SubtaskMetadataData
        """Gets the data of this SubtaskMetadata.


        :return: The data of this SubtaskMetadata.
        :rtype: SubtaskMetadataData
        """
        return self._data

    @data.setter
    def data(self, data):
        # type: (SubtaskMetadataData) -> None
        """Sets the data of this SubtaskMetadata.


        :param data: The data of this SubtaskMetadata.
        :type: SubtaskMetadataData
        """

        if data is not None:
            if not isinstance(data, SubtaskMetadataData):
                raise TypeError("Invalid type for `data`, type has to be `SubtaskMetadataData`")

        self._data = data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubtaskMetadata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class StreamsType(Enum):
    VIDEO = "VIDEO"
    LIVE = "LIVE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LimitTransformUnitDepthRecursionMode(Enum):
    DISABLED = "DISABLED"
    LEVEL_1 = "LEVEL_1"
    LEVEL_2 = "LEVEL_2"
    LEVEL_3 = "LEVEL_3"
    LEVEL_4 = "LEVEL_4"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class ConditionType(Enum):
    CONDITION = "CONDITION"
    AND = "AND"
    OR = "OR"



from bitmovin_api_sdk.encoding.encoding_api import EncodingApi
from bitmovin_api_sdk.encoding.inputs.inputs_api import InputsApi
from bitmovin_api_sdk.encoding.outputs.outputs_api import OutputsApi
from bitmovin_api_sdk.encoding.configurations.configurations_api import ConfigurationsApi
from bitmovin_api_sdk.encoding.filters.filters_api import FiltersApi
from bitmovin_api_sdk.encoding.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.live_api import LiveApi
from bitmovin_api_sdk.encoding.manifests.manifests_api import ManifestsApi
from bitmovin_api_sdk.encoding.infrastructure.infrastructure_api import InfrastructureApi
from bitmovin_api_sdk.encoding.statistics.statistics_api import StatisticsApi
from bitmovin_api_sdk.encoding.watch_folders.watch_folders_api import WatchFoldersApi
from bitmovin_api_sdk.encoding.error_definitions.error_definitions_api import ErrorDefinitionsApi
from bitmovin_api_sdk.encoding.templates.templates_api import TemplatesApi



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.audio_mix_channel_type import AudioMixChannelType
import pprint
import six


class AudioMixInputStreamChannel(object):
    @poscheck_model
    def __init__(self,
                 input_stream_id=None,
                 output_channel_type=None,
                 output_channel_number=None,
                 source_channels=None):
        # type: (string_types, AudioMixChannelType, int, list[AudioMixInputStreamSourceChannel]) -> None

        self._input_stream_id = None
        self._output_channel_type = None
        self._output_channel_number = None
        self._source_channels = list()
        self.discriminator = None

        if input_stream_id is not None:
            self.input_stream_id = input_stream_id
        if output_channel_type is not None:
            self.output_channel_type = output_channel_type
        if output_channel_number is not None:
            self.output_channel_number = output_channel_number
        if source_channels is not None:
            self.source_channels = source_channels

    @property
    def openapi_types(self):
        types = {
            'input_stream_id': 'string_types',
            'output_channel_type': 'AudioMixChannelType',
            'output_channel_number': 'int',
            'source_channels': 'list[AudioMixInputStreamSourceChannel]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'input_stream_id': 'inputStreamId',
            'output_channel_type': 'outputChannelType',
            'output_channel_number': 'outputChannelNumber',
            'source_channels': 'sourceChannels'
        }
        return attributes

    @property
    def input_stream_id(self):
        # type: () -> string_types
        """Gets the input_stream_id of this AudioMixInputStreamChannel.

        The id of the input stream that should be used for mixing.

        :return: The input_stream_id of this AudioMixInputStreamChannel.
        :rtype: string_types
        """
        return self._input_stream_id

    @input_stream_id.setter
    def input_stream_id(self, input_stream_id):
        # type: (string_types) -> None
        """Sets the input_stream_id of this AudioMixInputStreamChannel.

        The id of the input stream that should be used for mixing.

        :param input_stream_id: The input_stream_id of this AudioMixInputStreamChannel.
        :type: string_types
        """

        if input_stream_id is not None:
            if not isinstance(input_stream_id, string_types):
                raise TypeError("Invalid type for `input_stream_id`, type has to be `string_types`")

        self._input_stream_id = input_stream_id

    @property
    def output_channel_type(self):
        # type: () -> AudioMixChannelType
        """Gets the output_channel_type of this AudioMixInputStreamChannel.


        :return: The output_channel_type of this AudioMixInputStreamChannel.
        :rtype: AudioMixChannelType
        """
        return self._output_channel_type

    @output_channel_type.setter
    def output_channel_type(self, output_channel_type):
        # type: (AudioMixChannelType) -> None
        """Sets the output_channel_type of this AudioMixInputStreamChannel.


        :param output_channel_type: The output_channel_type of this AudioMixInputStreamChannel.
        :type: AudioMixChannelType
        """

        if output_channel_type is not None:
            if not isinstance(output_channel_type, AudioMixChannelType):
                raise TypeError("Invalid type for `output_channel_type`, type has to be `AudioMixChannelType`")

        self._output_channel_type = output_channel_type

    @property
    def output_channel_number(self):
        # type: () -> int
        """Gets the output_channel_number of this AudioMixInputStreamChannel.

        Number of this output channel. If type is 'CHANNEL_NUMBER', this must be set.

        :return: The output_channel_number of this AudioMixInputStreamChannel.
        :rtype: int
        """
        return self._output_channel_number

    @output_channel_number.setter
    def output_channel_number(self, output_channel_number):
        # type: (int) -> None
        """Sets the output_channel_number of this AudioMixInputStreamChannel.

        Number of this output channel. If type is 'CHANNEL_NUMBER', this must be set.

        :param output_channel_number: The output_channel_number of this AudioMixInputStreamChannel.
        :type: int
        """

        if output_channel_number is not None:
            if not isinstance(output_channel_number, int):
                raise TypeError("Invalid type for `output_channel_number`, type has to be `int`")

        self._output_channel_number = output_channel_number

    @property
    def source_channels(self):
        # type: () -> list[AudioMixInputStreamSourceChannel]
        """Gets the source_channels of this AudioMixInputStreamChannel.

        List of source channels to be mixed

        :return: The source_channels of this AudioMixInputStreamChannel.
        :rtype: list[AudioMixInputStreamSourceChannel]
        """
        return self._source_channels

    @source_channels.setter
    def source_channels(self, source_channels):
        # type: (list) -> None
        """Sets the source_channels of this AudioMixInputStreamChannel.

        List of source channels to be mixed

        :param source_channels: The source_channels of this AudioMixInputStreamChannel.
        :type: list[AudioMixInputStreamSourceChannel]
        """

        if source_channels is not None:
            if not isinstance(source_channels, list):
                raise TypeError("Invalid type for `source_channels`, type has to be `list[AudioMixInputStreamSourceChannel]`")

        self._source_channels = source_channels

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioMixInputStreamChannel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.manifests.hls.media.closed_captions.closed_captions_api import ClosedCaptionsApi
from bitmovin_api_sdk.encoding.manifests.hls.media.closed_captions.closed_captions_media_info_list_query_params import ClosedCaptionsMediaInfoListQueryParams



from bitmovin_api_sdk.encoding.filters.text.text_api import TextApi
from bitmovin_api_sdk.encoding.filters.text.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.text.text_filter_list_query_params import TextFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class S3AccessStyle(Enum):
    VIRTUAL_HOSTED = "VIRTUAL_HOSTED"
    PATH = "PATH"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class PixelFormat(Enum):
    YUV410P = "YUV410P"
    YUV411P = "YUV411P"
    YUV420P = "YUV420P"
    YUV422P = "YUV422P"
    YUV440P = "YUV440P"
    YUV444P = "YUV444P"
    YUVJ411P = "YUVJ411P"
    YUVJ420P = "YUVJ420P"
    YUVJ422P = "YUVJ422P"
    YUVJ440P = "YUVJ440P"
    YUVJ444P = "YUVJ444P"
    YUV420P10LE = "YUV420P10LE"
    YUV422P10LE = "YUV422P10LE"
    YUV440P10LE = "YUV440P10LE"
    YUV444P10LE = "YUV444P10LE"
    YUV420P12LE = "YUV420P12LE"
    YUV422P12LE = "YUV422P12LE"
    YUV440P12LE = "YUV440P12LE"
    YUV444P12LE = "YUV444P12LE"
    YUV420P10BE = "YUV420P10BE"
    YUV422P10BE = "YUV422P10BE"
    YUV440P10BE = "YUV440P10BE"
    YUV444P10BE = "YUV444P10BE"
    YUV420P12BE = "YUV420P12BE"
    YUV422P12BE = "YUV422P12BE"
    YUV440P12BE = "YUV440P12BE"
    YUV444P12BE = "YUV444P12BE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MvPredictionMode(Enum):
    NONE = "NONE"
    SPATIAL = "SPATIAL"
    TEMPORAL = "TEMPORAL"
    AUTO = "AUTO"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class SubtaskMetadataData(object):
    @poscheck_model
    def __init__(self,
                 avg_frames_encoded_per_second=None,
                 bytes_encoded=None,
                 frames_analysed=None,
                 frames_encoded=None,
                 realtime_factor=None,
                 size=None):
        # type: (float, int, int, int, float, int) -> None

        self._avg_frames_encoded_per_second = None
        self._bytes_encoded = None
        self._frames_analysed = None
        self._frames_encoded = None
        self._realtime_factor = None
        self._size = None
        self.discriminator = None

        if avg_frames_encoded_per_second is not None:
            self.avg_frames_encoded_per_second = avg_frames_encoded_per_second
        if bytes_encoded is not None:
            self.bytes_encoded = bytes_encoded
        if frames_analysed is not None:
            self.frames_analysed = frames_analysed
        if frames_encoded is not None:
            self.frames_encoded = frames_encoded
        if realtime_factor is not None:
            self.realtime_factor = realtime_factor
        if size is not None:
            self.size = size

    @property
    def openapi_types(self):
        types = {
            'avg_frames_encoded_per_second': 'float',
            'bytes_encoded': 'int',
            'frames_analysed': 'int',
            'frames_encoded': 'int',
            'realtime_factor': 'float',
            'size': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'avg_frames_encoded_per_second': 'avgFramesEncodedPerSecond',
            'bytes_encoded': 'bytesEncoded',
            'frames_analysed': 'framesAnalysed',
            'frames_encoded': 'framesEncoded',
            'realtime_factor': 'realtimeFactor',
            'size': 'size'
        }
        return attributes

    @property
    def avg_frames_encoded_per_second(self):
        # type: () -> float
        """Gets the avg_frames_encoded_per_second of this SubtaskMetadataData.


        :return: The avg_frames_encoded_per_second of this SubtaskMetadataData.
        :rtype: float
        """
        return self._avg_frames_encoded_per_second

    @avg_frames_encoded_per_second.setter
    def avg_frames_encoded_per_second(self, avg_frames_encoded_per_second):
        # type: (float) -> None
        """Sets the avg_frames_encoded_per_second of this SubtaskMetadataData.


        :param avg_frames_encoded_per_second: The avg_frames_encoded_per_second of this SubtaskMetadataData.
        :type: float
        """

        if avg_frames_encoded_per_second is not None:
            if not isinstance(avg_frames_encoded_per_second, (float, int)):
                raise TypeError("Invalid type for `avg_frames_encoded_per_second`, type has to be `float`")

        self._avg_frames_encoded_per_second = avg_frames_encoded_per_second

    @property
    def bytes_encoded(self):
        # type: () -> int
        """Gets the bytes_encoded of this SubtaskMetadataData.


        :return: The bytes_encoded of this SubtaskMetadataData.
        :rtype: int
        """
        return self._bytes_encoded

    @bytes_encoded.setter
    def bytes_encoded(self, bytes_encoded):
        # type: (int) -> None
        """Sets the bytes_encoded of this SubtaskMetadataData.


        :param bytes_encoded: The bytes_encoded of this SubtaskMetadataData.
        :type: int
        """

        if bytes_encoded is not None:
            if not isinstance(bytes_encoded, int):
                raise TypeError("Invalid type for `bytes_encoded`, type has to be `int`")

        self._bytes_encoded = bytes_encoded

    @property
    def frames_analysed(self):
        # type: () -> int
        """Gets the frames_analysed of this SubtaskMetadataData.


        :return: The frames_analysed of this SubtaskMetadataData.
        :rtype: int
        """
        return self._frames_analysed

    @frames_analysed.setter
    def frames_analysed(self, frames_analysed):
        # type: (int) -> None
        """Sets the frames_analysed of this SubtaskMetadataData.


        :param frames_analysed: The frames_analysed of this SubtaskMetadataData.
        :type: int
        """

        if frames_analysed is not None:
            if not isinstance(frames_analysed, int):
                raise TypeError("Invalid type for `frames_analysed`, type has to be `int`")

        self._frames_analysed = frames_analysed

    @property
    def frames_encoded(self):
        # type: () -> int
        """Gets the frames_encoded of this SubtaskMetadataData.


        :return: The frames_encoded of this SubtaskMetadataData.
        :rtype: int
        """
        return self._frames_encoded

    @frames_encoded.setter
    def frames_encoded(self, frames_encoded):
        # type: (int) -> None
        """Sets the frames_encoded of this SubtaskMetadataData.


        :param frames_encoded: The frames_encoded of this SubtaskMetadataData.
        :type: int
        """

        if frames_encoded is not None:
            if not isinstance(frames_encoded, int):
                raise TypeError("Invalid type for `frames_encoded`, type has to be `int`")

        self._frames_encoded = frames_encoded

    @property
    def realtime_factor(self):
        # type: () -> float
        """Gets the realtime_factor of this SubtaskMetadataData.


        :return: The realtime_factor of this SubtaskMetadataData.
        :rtype: float
        """
        return self._realtime_factor

    @realtime_factor.setter
    def realtime_factor(self, realtime_factor):
        # type: (float) -> None
        """Sets the realtime_factor of this SubtaskMetadataData.


        :param realtime_factor: The realtime_factor of this SubtaskMetadataData.
        :type: float
        """

        if realtime_factor is not None:
            if not isinstance(realtime_factor, (float, int)):
                raise TypeError("Invalid type for `realtime_factor`, type has to be `float`")

        self._realtime_factor = realtime_factor

    @property
    def size(self):
        # type: () -> int
        """Gets the size of this SubtaskMetadataData.


        :return: The size of this SubtaskMetadataData.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        # type: (int) -> None
        """Sets the size of this SubtaskMetadataData.


        :param size: The size of this SubtaskMetadataData.
        :type: int
        """

        if size is not None:
            if not isinstance(size, int):
                raise TypeError("Invalid type for `size`, type has to be `int`")

        self._size = size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SubtaskMetadataData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.encodings.muxings.progressive_wav.progressive_wav_api import ProgressiveWavApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_wav.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_wav.information.information_api import InformationApi
from bitmovin_api_sdk.encoding.encodings.muxings.progressive_wav.progressive_wav_muxing_list_query_params import ProgressiveWavMuxingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class OrganizationType(Enum):
    ROOT_ORGANIZATION = "ROOT_ORGANIZATION"
    SUB_ORGANIZATION = "SUB_ORGANIZATION"



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.https_input import HttpsInput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.inputs.https.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.inputs.https.https_input_list_query_params import HttpsInputListQueryParams


class HttpsApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(HttpsApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, https_input, **kwargs):
        # type: (HttpsInput, dict) -> HttpsInput
        """Create HTTPS Input

        :param https_input: The Https input to be created
        :type https_input: HttpsInput, required
        :return: HTTPS input
        :rtype: HttpsInput
        """

        return self.api_client.post(
            '/encoding/inputs/https',
            https_input,
            type=HttpsInput,
            **kwargs
        )

    def delete(self, input_id, **kwargs):
        # type: (string_types, dict) -> HttpsInput
        """Delete HTTPS Input

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: Id of the input
        :rtype: HttpsInput
        """

        return self.api_client.delete(
            '/encoding/inputs/https/{input_id}',
            path_params={'input_id': input_id},
            type=HttpsInput,
            **kwargs
        )

    def get(self, input_id, **kwargs):
        # type: (string_types, dict) -> HttpsInput
        """HTTPS Input Details

        :param input_id: Id of the input
        :type input_id: string_types, required
        :return: HTTPS input
        :rtype: HttpsInput
        """

        return self.api_client.get(
            '/encoding/inputs/https/{input_id}',
            path_params={'input_id': input_id},
            type=HttpsInput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (HttpsInputListQueryParams, dict) -> HttpsInput
        """List HTTPS Inputs

        :param query_params: Query parameters
        :type query_params: HttpsInputListQueryParams
        :return: List of HTTPS inputs
        :rtype: HttpsInput
        """

        return self.api_client.get(
            '/encoding/inputs/https',
            query_params=query_params,
            pagination_response=True,
            type=HttpsInput,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class EncodingStreamInputDetails(object):
    @poscheck_model
    def __init__(self,
                 format_name=None,
                 start_time=None,
                 duration=None,
                 size=None,
                 bitrate=None,
                 tags=None,
                 video_streams=None,
                 audio_streams=None,
                 meta_streams=None,
                 subtitle_streams=None):
        # type: (string_types, float, float, int, int, dict, list[VideoStream], list[AudioStream], list[MediaStream], list[SubtitleStream]) -> None

        self._format_name = None
        self._start_time = None
        self._duration = None
        self._size = None
        self._bitrate = None
        self._tags = None
        self._video_streams = list()
        self._audio_streams = list()
        self._meta_streams = list()
        self._subtitle_streams = list()
        self.discriminator = None

        if format_name is not None:
            self.format_name = format_name
        if start_time is not None:
            self.start_time = start_time
        if duration is not None:
            self.duration = duration
        if size is not None:
            self.size = size
        if bitrate is not None:
            self.bitrate = bitrate
        if tags is not None:
            self.tags = tags
        if video_streams is not None:
            self.video_streams = video_streams
        if audio_streams is not None:
            self.audio_streams = audio_streams
        if meta_streams is not None:
            self.meta_streams = meta_streams
        if subtitle_streams is not None:
            self.subtitle_streams = subtitle_streams

    @property
    def openapi_types(self):
        types = {
            'format_name': 'string_types',
            'start_time': 'float',
            'duration': 'float',
            'size': 'int',
            'bitrate': 'int',
            'tags': 'dict(str, object)',
            'video_streams': 'list[VideoStream]',
            'audio_streams': 'list[AudioStream]',
            'meta_streams': 'list[MediaStream]',
            'subtitle_streams': 'list[SubtitleStream]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'format_name': 'formatName',
            'start_time': 'startTime',
            'duration': 'duration',
            'size': 'size',
            'bitrate': 'bitrate',
            'tags': 'tags',
            'video_streams': 'videoStreams',
            'audio_streams': 'audioStreams',
            'meta_streams': 'metaStreams',
            'subtitle_streams': 'subtitleStreams'
        }
        return attributes

    @property
    def format_name(self):
        # type: () -> string_types
        """Gets the format_name of this EncodingStreamInputDetails.

        Format name

        :return: The format_name of this EncodingStreamInputDetails.
        :rtype: string_types
        """
        return self._format_name

    @format_name.setter
    def format_name(self, format_name):
        # type: (string_types) -> None
        """Sets the format_name of this EncodingStreamInputDetails.

        Format name

        :param format_name: The format_name of this EncodingStreamInputDetails.
        :type: string_types
        """

        if format_name is not None:
            if not isinstance(format_name, string_types):
                raise TypeError("Invalid type for `format_name`, type has to be `string_types`")

        self._format_name = format_name

    @property
    def start_time(self):
        # type: () -> float
        """Gets the start_time of this EncodingStreamInputDetails.

        The start time in seconds

        :return: The start_time of this EncodingStreamInputDetails.
        :rtype: float
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        # type: (float) -> None
        """Sets the start_time of this EncodingStreamInputDetails.

        The start time in seconds

        :param start_time: The start_time of this EncodingStreamInputDetails.
        :type: float
        """

        if start_time is not None:
            if not isinstance(start_time, (float, int)):
                raise TypeError("Invalid type for `start_time`, type has to be `float`")

        self._start_time = start_time

    @property
    def duration(self):
        # type: () -> float
        """Gets the duration of this EncodingStreamInputDetails.

        Duration in seconds

        :return: The duration of this EncodingStreamInputDetails.
        :rtype: float
        """
        return self._duration

    @duration.setter
    def duration(self, duration):
        # type: (float) -> None
        """Sets the duration of this EncodingStreamInputDetails.

        Duration in seconds

        :param duration: The duration of this EncodingStreamInputDetails.
        :type: float
        """

        if duration is not None:
            if not isinstance(duration, (float, int)):
                raise TypeError("Invalid type for `duration`, type has to be `float`")

        self._duration = duration

    @property
    def size(self):
        # type: () -> int
        """Gets the size of this EncodingStreamInputDetails.

        Input file size in bytes

        :return: The size of this EncodingStreamInputDetails.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        # type: (int) -> None
        """Sets the size of this EncodingStreamInputDetails.

        Input file size in bytes

        :param size: The size of this EncodingStreamInputDetails.
        :type: int
        """

        if size is not None:
            if not isinstance(size, int):
                raise TypeError("Invalid type for `size`, type has to be `int`")

        self._size = size

    @property
    def bitrate(self):
        # type: () -> int
        """Gets the bitrate of this EncodingStreamInputDetails.

        Bitrate in bps

        :return: The bitrate of this EncodingStreamInputDetails.
        :rtype: int
        """
        return self._bitrate

    @bitrate.setter
    def bitrate(self, bitrate):
        # type: (int) -> None
        """Sets the bitrate of this EncodingStreamInputDetails.

        Bitrate in bps

        :param bitrate: The bitrate of this EncodingStreamInputDetails.
        :type: int
        """

        if bitrate is not None:
            if not isinstance(bitrate, int):
                raise TypeError("Invalid type for `bitrate`, type has to be `int`")

        self._bitrate = bitrate

    @property
    def tags(self):
        # type: () -> dict(str, object)
        """Gets the tags of this EncodingStreamInputDetails.

        Additional metadata saved in the input file

        :return: The tags of this EncodingStreamInputDetails.
        :rtype: dict(str, object)
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        # type: (dict) -> None
        """Sets the tags of this EncodingStreamInputDetails.

        Additional metadata saved in the input file

        :param tags: The tags of this EncodingStreamInputDetails.
        :type: dict(str, object)
        """

        if tags is not None:
            if not isinstance(tags, dict):
                raise TypeError("Invalid type for `tags`, type has to be `dict(str, object)`")

        self._tags = tags

    @property
    def video_streams(self):
        # type: () -> list[VideoStream]
        """Gets the video_streams of this EncodingStreamInputDetails.

        Video streams in the input file

        :return: The video_streams of this EncodingStreamInputDetails.
        :rtype: list[VideoStream]
        """
        return self._video_streams

    @video_streams.setter
    def video_streams(self, video_streams):
        # type: (list) -> None
        """Sets the video_streams of this EncodingStreamInputDetails.

        Video streams in the input file

        :param video_streams: The video_streams of this EncodingStreamInputDetails.
        :type: list[VideoStream]
        """

        if video_streams is not None:
            if not isinstance(video_streams, list):
                raise TypeError("Invalid type for `video_streams`, type has to be `list[VideoStream]`")

        self._video_streams = video_streams

    @property
    def audio_streams(self):
        # type: () -> list[AudioStream]
        """Gets the audio_streams of this EncodingStreamInputDetails.

        Audio stream in the input file

        :return: The audio_streams of this EncodingStreamInputDetails.
        :rtype: list[AudioStream]
        """
        return self._audio_streams

    @audio_streams.setter
    def audio_streams(self, audio_streams):
        # type: (list) -> None
        """Sets the audio_streams of this EncodingStreamInputDetails.

        Audio stream in the input file

        :param audio_streams: The audio_streams of this EncodingStreamInputDetails.
        :type: list[AudioStream]
        """

        if audio_streams is not None:
            if not isinstance(audio_streams, list):
                raise TypeError("Invalid type for `audio_streams`, type has to be `list[AudioStream]`")

        self._audio_streams = audio_streams

    @property
    def meta_streams(self):
        # type: () -> list[MediaStream]
        """Gets the meta_streams of this EncodingStreamInputDetails.

        Meta data streams in the input file

        :return: The meta_streams of this EncodingStreamInputDetails.
        :rtype: list[MediaStream]
        """
        return self._meta_streams

    @meta_streams.setter
    def meta_streams(self, meta_streams):
        # type: (list) -> None
        """Sets the meta_streams of this EncodingStreamInputDetails.

        Meta data streams in the input file

        :param meta_streams: The meta_streams of this EncodingStreamInputDetails.
        :type: list[MediaStream]
        """

        if meta_streams is not None:
            if not isinstance(meta_streams, list):
                raise TypeError("Invalid type for `meta_streams`, type has to be `list[MediaStream]`")

        self._meta_streams = meta_streams

    @property
    def subtitle_streams(self):
        # type: () -> list[SubtitleStream]
        """Gets the subtitle_streams of this EncodingStreamInputDetails.

        Subtitle streams in the input file

        :return: The subtitle_streams of this EncodingStreamInputDetails.
        :rtype: list[SubtitleStream]
        """
        return self._subtitle_streams

    @subtitle_streams.setter
    def subtitle_streams(self, subtitle_streams):
        # type: (list) -> None
        """Sets the subtitle_streams of this EncodingStreamInputDetails.

        Subtitle streams in the input file

        :param subtitle_streams: The subtitle_streams of this EncodingStreamInputDetails.
        :type: list[SubtitleStream]
        """

        if subtitle_streams is not None:
            if not isinstance(subtitle_streams, list):
                raise TypeError("Invalid type for `subtitle_streams`, type has to be `list[SubtitleStream]`")

        self._subtitle_streams = subtitle_streams

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EncodingStreamInputDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.account.organizations.organizations_api import OrganizationsApi
from bitmovin_api_sdk.account.organizations.sub_organizations.sub_organizations_api import SubOrganizationsApi
from bitmovin_api_sdk.account.organizations.tenants.tenants_api import TenantsApi
from bitmovin_api_sdk.account.organizations.invitations.invitations_api import InvitationsApi
from bitmovin_api_sdk.account.organizations.groups.groups_api import GroupsApi



from bitmovin_api_sdk.encoding.filters.crop.crop_api import CropApi
from bitmovin_api_sdk.encoding.filters.crop.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.filters.crop.crop_filter_list_query_params import CropFilterListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dash_representation import DashRepresentation
import pprint
import six


class SpriteRepresentation(DashRepresentation):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 encoding_id=None,
                 stream_id=None,
                 sprite_id=None,
                 segment_path=None):
        # type: (string_types, string_types, string_types, string_types, string_types) -> None
        super(SpriteRepresentation, self).__init__(id_=id_)

        self._encoding_id = None
        self._stream_id = None
        self._sprite_id = None
        self._segment_path = None
        self.discriminator = None

        if encoding_id is not None:
            self.encoding_id = encoding_id
        if stream_id is not None:
            self.stream_id = stream_id
        if sprite_id is not None:
            self.sprite_id = sprite_id
        if segment_path is not None:
            self.segment_path = segment_path

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(SpriteRepresentation, self), 'openapi_types'):
            types = getattr(super(SpriteRepresentation, self), 'openapi_types')

        types.update({
            'encoding_id': 'string_types',
            'stream_id': 'string_types',
            'sprite_id': 'string_types',
            'segment_path': 'string_types'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(SpriteRepresentation, self), 'attribute_map'):
            attributes = getattr(super(SpriteRepresentation, self), 'attribute_map')

        attributes.update({
            'encoding_id': 'encodingId',
            'stream_id': 'streamId',
            'sprite_id': 'spriteId',
            'segment_path': 'segmentPath'
        })
        return attributes

    @property
    def encoding_id(self):
        # type: () -> string_types
        """Gets the encoding_id of this SpriteRepresentation.

        UUID of an encoding (required)

        :return: The encoding_id of this SpriteRepresentation.
        :rtype: string_types
        """
        return self._encoding_id

    @encoding_id.setter
    def encoding_id(self, encoding_id):
        # type: (string_types) -> None
        """Sets the encoding_id of this SpriteRepresentation.

        UUID of an encoding (required)

        :param encoding_id: The encoding_id of this SpriteRepresentation.
        :type: string_types
        """

        if encoding_id is not None:
            if not isinstance(encoding_id, string_types):
                raise TypeError("Invalid type for `encoding_id`, type has to be `string_types`")

        self._encoding_id = encoding_id

    @property
    def stream_id(self):
        # type: () -> string_types
        """Gets the stream_id of this SpriteRepresentation.

        UUID of a stream (required)

        :return: The stream_id of this SpriteRepresentation.
        :rtype: string_types
        """
        return self._stream_id

    @stream_id.setter
    def stream_id(self, stream_id):
        # type: (string_types) -> None
        """Sets the stream_id of this SpriteRepresentation.

        UUID of a stream (required)

        :param stream_id: The stream_id of this SpriteRepresentation.
        :type: string_types
        """

        if stream_id is not None:
            if not isinstance(stream_id, string_types):
                raise TypeError("Invalid type for `stream_id`, type has to be `string_types`")

        self._stream_id = stream_id

    @property
    def sprite_id(self):
        # type: () -> string_types
        """Gets the sprite_id of this SpriteRepresentation.

        UUID of a Sprite (required)

        :return: The sprite_id of this SpriteRepresentation.
        :rtype: string_types
        """
        return self._sprite_id

    @sprite_id.setter
    def sprite_id(self, sprite_id):
        # type: (string_types) -> None
        """Sets the sprite_id of this SpriteRepresentation.

        UUID of a Sprite (required)

        :param sprite_id: The sprite_id of this SpriteRepresentation.
        :type: string_types
        """

        if sprite_id is not None:
            if not isinstance(sprite_id, string_types):
                raise TypeError("Invalid type for `sprite_id`, type has to be `string_types`")

        self._sprite_id = sprite_id

    @property
    def segment_path(self):
        # type: () -> string_types
        """Gets the segment_path of this SpriteRepresentation.

        Path to sprite segments. Will be used as the representation id in the manifest. (required)

        :return: The segment_path of this SpriteRepresentation.
        :rtype: string_types
        """
        return self._segment_path

    @segment_path.setter
    def segment_path(self, segment_path):
        # type: (string_types) -> None
        """Sets the segment_path of this SpriteRepresentation.

        Path to sprite segments. Will be used as the representation id in the manifest. (required)

        :param segment_path: The segment_path of this SpriteRepresentation.
        :type: string_types
        """

        if segment_path is not None:
            if not isinstance(segment_path, string_types):
                raise TypeError("Invalid type for `segment_path`, type has to be `string_types`")

        self._segment_path = segment_path

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(SpriteRepresentation, self), "to_dict"):
            result = super(SpriteRepresentation, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SpriteRepresentation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class MessageType(Enum):
    ERROR = "ERROR"
    WARNING = "WARNING"
    INFO = "INFO"
    DEBUG = "DEBUG"
    TRACE = "TRACE"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.variant_stream_dropping_mode import VariantStreamDroppingMode
import pprint
import six


class AudioGroupConfiguration(object):
    @poscheck_model
    def __init__(self,
                 dropping_mode=None,
                 groups=None):
        # type: (VariantStreamDroppingMode, list[AudioGroup]) -> None

        self._dropping_mode = None
        self._groups = list()
        self.discriminator = None

        if dropping_mode is not None:
            self.dropping_mode = dropping_mode
        if groups is not None:
            self.groups = groups

    @property
    def openapi_types(self):
        types = {
            'dropping_mode': 'VariantStreamDroppingMode',
            'groups': 'list[AudioGroup]'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'dropping_mode': 'droppingMode',
            'groups': 'groups'
        }
        return attributes

    @property
    def dropping_mode(self):
        # type: () -> VariantStreamDroppingMode
        """Gets the dropping_mode of this AudioGroupConfiguration.

        Dropping mode (required)

        :return: The dropping_mode of this AudioGroupConfiguration.
        :rtype: VariantStreamDroppingMode
        """
        return self._dropping_mode

    @dropping_mode.setter
    def dropping_mode(self, dropping_mode):
        # type: (VariantStreamDroppingMode) -> None
        """Sets the dropping_mode of this AudioGroupConfiguration.

        Dropping mode (required)

        :param dropping_mode: The dropping_mode of this AudioGroupConfiguration.
        :type: VariantStreamDroppingMode
        """

        if dropping_mode is not None:
            if not isinstance(dropping_mode, VariantStreamDroppingMode):
                raise TypeError("Invalid type for `dropping_mode`, type has to be `VariantStreamDroppingMode`")

        self._dropping_mode = dropping_mode

    @property
    def groups(self):
        # type: () -> list[AudioGroup]
        """Gets the groups of this AudioGroupConfiguration.

        Audio groups (required)

        :return: The groups of this AudioGroupConfiguration.
        :rtype: list[AudioGroup]
        """
        return self._groups

    @groups.setter
    def groups(self, groups):
        # type: (list) -> None
        """Sets the groups of this AudioGroupConfiguration.

        Audio groups (required)

        :param groups: The groups of this AudioGroupConfiguration.
        :type: list[AudioGroup]
        """

        if groups is not None:
            if not isinstance(groups, list):
                raise TypeError("Invalid type for `groups`, type has to be `list[AudioGroup]`")

        self._groups = groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AudioGroupConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.ftp_output import FtpOutput
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.outputs.ftp.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.outputs.ftp.ftp_output_list_query_params import FtpOutputListQueryParams


class FtpApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(FtpApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

        self.customdata = CustomdataApi(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, ftp_output, **kwargs):
        # type: (FtpOutput, dict) -> FtpOutput
        """Create FTP Output

        :param ftp_output: The FTP output to be created
        :type ftp_output: FtpOutput, required
        :return: FTP output
        :rtype: FtpOutput
        """

        return self.api_client.post(
            '/encoding/outputs/ftp',
            ftp_output,
            type=FtpOutput,
            **kwargs
        )

    def delete(self, output_id, **kwargs):
        # type: (string_types, dict) -> FtpOutput
        """Delete FTP Output

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: Id of the output
        :rtype: FtpOutput
        """

        return self.api_client.delete(
            '/encoding/outputs/ftp/{output_id}',
            path_params={'output_id': output_id},
            type=FtpOutput,
            **kwargs
        )

    def get(self, output_id, **kwargs):
        # type: (string_types, dict) -> FtpOutput
        """FTP Output Details

        :param output_id: Id of the output
        :type output_id: string_types, required
        :return: FTP output
        :rtype: FtpOutput
        """

        return self.api_client.get(
            '/encoding/outputs/ftp/{output_id}',
            path_params={'output_id': output_id},
            type=FtpOutput,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (FtpOutputListQueryParams, dict) -> FtpOutput
        """List FTP Outputs

        :param query_params: Query parameters
        :type query_params: FtpOutputListQueryParams
        :return: List of FTP outputs
        :rtype: FtpOutput
        """

        return self.api_client.get(
            '/encoding/outputs/ftp',
            query_params=query_params,
            pagination_response=True,
            type=FtpOutput,
            **kwargs
        )



from bitmovin_api_sdk.models import StreamsType
from bitmovin_api_sdk.models import StreamsVideoStatus


class StreamsResponseListQueryParams(object):
    def __init__(self, offset=None, limit=None, query=None, type_=None, status=None, created_before=None, created_after=None, signed=None, domain_restricted=None):
        # type: (int, int, string_types, StreamsType, StreamsVideoStatus, string_types, string_types, bool, bool) -> None
        super(StreamsResponseListQueryParams, self).__init__()

        self.offset = offset
        self.limit = limit
        self.query = query
        self.type = type_
        self.status = status
        self.created_before = created_before
        self.created_after = created_after
        self.signed = signed
        self.domain_restricted = domain_restricted

    @property
    def openapi_types(self):
        types = {
            'offset': 'int',
            'limit': 'int',
            'query': 'string_types',
            'type': 'StreamsType',
            'status': 'StreamsVideoStatus',
            'created_before': 'string_types',
            'created_after': 'string_types',
            'signed': 'bool',
            'domain_restricted': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'offset': 'offset',
            'limit': 'limit',
            'query': 'query',
            'type': 'type',
            'status': 'status',
            'created_before': 'createdBefore',
            'created_after': 'createdAfter',
            'signed': 'signed',
            'domain_restricted': 'domainRestricted'
        }

        return attributes



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
import pprint
import six


class Notification(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 resolve=None,
                 resource_id=None,
                 triggered_at=None,
                 type_=None,
                 event_type=None,
                 category=None,
                 resource_type=None,
                 muted=None,
                 custom_data=None):
        # type: (string_types, bool, string_types, datetime, string_types, string_types, string_types, string_types, bool, dict) -> None
        super(Notification, self).__init__(id_=id_)

        self._resolve = None
        self._resource_id = None
        self._triggered_at = None
        self._type = None
        self._event_type = None
        self._category = None
        self._resource_type = None
        self._muted = None
        self._custom_data = None
        self.discriminator = None

        if resolve is not None:
            self.resolve = resolve
        if resource_id is not None:
            self.resource_id = resource_id
        if triggered_at is not None:
            self.triggered_at = triggered_at
        if type_ is not None:
            self.type = type_
        if event_type is not None:
            self.event_type = event_type
        if category is not None:
            self.category = category
        if resource_type is not None:
            self.resource_type = resource_type
        if muted is not None:
            self.muted = muted
        if custom_data is not None:
            self.custom_data = custom_data

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Notification, self), 'openapi_types'):
            types = getattr(super(Notification, self), 'openapi_types')

        types.update({
            'resolve': 'bool',
            'resource_id': 'string_types',
            'triggered_at': 'datetime',
            'type': 'string_types',
            'event_type': 'string_types',
            'category': 'string_types',
            'resource_type': 'string_types',
            'muted': 'bool',
            'custom_data': 'dict(str, object)'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Notification, self), 'attribute_map'):
            attributes = getattr(super(Notification, self), 'attribute_map')

        attributes.update({
            'resolve': 'resolve',
            'resource_id': 'resourceId',
            'triggered_at': 'triggeredAt',
            'type': 'type',
            'event_type': 'eventType',
            'category': 'category',
            'resource_type': 'resourceType',
            'muted': 'muted',
            'custom_data': 'customData'
        })
        return attributes

    @property
    def resolve(self):
        # type: () -> bool
        """Gets the resolve of this Notification.

        Notify when condition resolves after it was met

        :return: The resolve of this Notification.
        :rtype: bool
        """
        return self._resolve

    @resolve.setter
    def resolve(self, resolve):
        # type: (bool) -> None
        """Sets the resolve of this Notification.

        Notify when condition resolves after it was met

        :param resolve: The resolve of this Notification.
        :type: bool
        """

        if resolve is not None:
            if not isinstance(resolve, bool):
                raise TypeError("Invalid type for `resolve`, type has to be `bool`")

        self._resolve = resolve

    @property
    def resource_id(self):
        # type: () -> string_types
        """Gets the resource_id of this Notification.

        Specific resource, e.g. encoding id

        :return: The resource_id of this Notification.
        :rtype: string_types
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        # type: (string_types) -> None
        """Sets the resource_id of this Notification.

        Specific resource, e.g. encoding id

        :param resource_id: The resource_id of this Notification.
        :type: string_types
        """

        if resource_id is not None:
            if not isinstance(resource_id, string_types):
                raise TypeError("Invalid type for `resource_id`, type has to be `string_types`")

        self._resource_id = resource_id

    @property
    def triggered_at(self):
        # type: () -> datetime
        """Gets the triggered_at of this Notification.

        Last time the notification was triggered

        :return: The triggered_at of this Notification.
        :rtype: datetime
        """
        return self._triggered_at

    @triggered_at.setter
    def triggered_at(self, triggered_at):
        # type: (datetime) -> None
        """Sets the triggered_at of this Notification.

        Last time the notification was triggered

        :param triggered_at: The triggered_at of this Notification.
        :type: datetime
        """

        if triggered_at is not None:
            if not isinstance(triggered_at, datetime):
                raise TypeError("Invalid type for `triggered_at`, type has to be `datetime`")

        self._triggered_at = triggered_at

    @property
    def type(self):
        # type: () -> string_types
        """Gets the type of this Notification.


        :return: The type of this Notification.
        :rtype: string_types
        """
        return self._type

    @type.setter
    def type(self, type_):
        # type: (string_types) -> None
        """Sets the type of this Notification.


        :param type_: The type of this Notification.
        :type: string_types
        """

        if type_ is not None:
            if not isinstance(type_, string_types):
                raise TypeError("Invalid type for `type`, type has to be `string_types`")

        self._type = type_

    @property
    def event_type(self):
        # type: () -> string_types
        """Gets the event_type of this Notification.


        :return: The event_type of this Notification.
        :rtype: string_types
        """
        return self._event_type

    @event_type.setter
    def event_type(self, event_type):
        # type: (string_types) -> None
        """Sets the event_type of this Notification.


        :param event_type: The event_type of this Notification.
        :type: string_types
        """

        if event_type is not None:
            if not isinstance(event_type, string_types):
                raise TypeError("Invalid type for `event_type`, type has to be `string_types`")

        self._event_type = event_type

    @property
    def category(self):
        # type: () -> string_types
        """Gets the category of this Notification.


        :return: The category of this Notification.
        :rtype: string_types
        """
        return self._category

    @category.setter
    def category(self, category):
        # type: (string_types) -> None
        """Sets the category of this Notification.


        :param category: The category of this Notification.
        :type: string_types
        """

        if category is not None:
            if not isinstance(category, string_types):
                raise TypeError("Invalid type for `category`, type has to be `string_types`")

        self._category = category

    @property
    def resource_type(self):
        # type: () -> string_types
        """Gets the resource_type of this Notification.


        :return: The resource_type of this Notification.
        :rtype: string_types
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        # type: (string_types) -> None
        """Sets the resource_type of this Notification.


        :param resource_type: The resource_type of this Notification.
        :type: string_types
        """

        if resource_type is not None:
            if not isinstance(resource_type, string_types):
                raise TypeError("Invalid type for `resource_type`, type has to be `string_types`")

        self._resource_type = resource_type

    @property
    def muted(self):
        # type: () -> bool
        """Gets the muted of this Notification.


        :return: The muted of this Notification.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        # type: (bool) -> None
        """Sets the muted of this Notification.


        :param muted: The muted of this Notification.
        :type: bool
        """

        if muted is not None:
            if not isinstance(muted, bool):
                raise TypeError("Invalid type for `muted`, type has to be `bool`")

        self._muted = muted

    @property
    def custom_data(self):
        # type: () -> dict(str, object)
        """Gets the custom_data of this Notification.

        User-specific meta data. This can hold anything.

        :return: The custom_data of this Notification.
        :rtype: dict(str, object)
        """
        return self._custom_data

    @custom_data.setter
    def custom_data(self, custom_data):
        # type: (dict) -> None
        """Sets the custom_data of this Notification.

        User-specific meta data. This can hold anything.

        :param custom_data: The custom_data of this Notification.
        :type: dict(str, object)
        """

        if custom_data is not None:
            if not isinstance(custom_data, dict):
                raise TypeError("Invalid type for `custom_data`, type has to be `dict(str, object)`")

        self._custom_data = custom_data

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Notification, self), "to_dict"):
            result = super(Notification, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Notification):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.statistics import Statistics
import pprint
import six


class StatisticsPerLabel(Statistics):
    @poscheck_model
    def __init__(self,
                 bytes_encoded_total=None,
                 time_encoded_total=None,
                 bytes_egress_total=None,
                 label=None,
                 billable_minutes=None,
                 billable_encoding_minutes=None,
                 billable_transmuxing_minutes=None,
                 billable_feature_minutes=None,
                 billable_egress_bytes=None):
        # type: (int, int, int, string_types, float, list[BillableEncodingMinutes], float, list[BillableEncodingFeatureMinutes], list[EgressInformation]) -> None
        super(StatisticsPerLabel, self).__init__(bytes_encoded_total=bytes_encoded_total, time_encoded_total=time_encoded_total, bytes_egress_total=bytes_egress_total)

        self._label = None
        self._billable_minutes = None
        self._billable_encoding_minutes = list()
        self._billable_transmuxing_minutes = None
        self._billable_feature_minutes = list()
        self._billable_egress_bytes = list()
        self.discriminator = None

        if label is not None:
            self.label = label
        if billable_minutes is not None:
            self.billable_minutes = billable_minutes
        if billable_encoding_minutes is not None:
            self.billable_encoding_minutes = billable_encoding_minutes
        if billable_transmuxing_minutes is not None:
            self.billable_transmuxing_minutes = billable_transmuxing_minutes
        if billable_feature_minutes is not None:
            self.billable_feature_minutes = billable_feature_minutes
        if billable_egress_bytes is not None:
            self.billable_egress_bytes = billable_egress_bytes

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(StatisticsPerLabel, self), 'openapi_types'):
            types = getattr(super(StatisticsPerLabel, self), 'openapi_types')

        types.update({
            'label': 'string_types',
            'billable_minutes': 'float',
            'billable_encoding_minutes': 'list[BillableEncodingMinutes]',
            'billable_transmuxing_minutes': 'float',
            'billable_feature_minutes': 'list[BillableEncodingFeatureMinutes]',
            'billable_egress_bytes': 'list[EgressInformation]'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(StatisticsPerLabel, self), 'attribute_map'):
            attributes = getattr(super(StatisticsPerLabel, self), 'attribute_map')

        attributes.update({
            'label': 'label',
            'billable_minutes': 'billableMinutes',
            'billable_encoding_minutes': 'billableEncodingMinutes',
            'billable_transmuxing_minutes': 'billableTransmuxingMinutes',
            'billable_feature_minutes': 'billableFeatureMinutes',
            'billable_egress_bytes': 'billableEgressBytes'
        })
        return attributes

    @property
    def label(self):
        # type: () -> string_types
        """Gets the label of this StatisticsPerLabel.

        An optional error message, when the event is in error state (occurs at event: ERROR) (required)

        :return: The label of this StatisticsPerLabel.
        :rtype: string_types
        """
        return self._label

    @label.setter
    def label(self, label):
        # type: (string_types) -> None
        """Sets the label of this StatisticsPerLabel.

        An optional error message, when the event is in error state (occurs at event: ERROR) (required)

        :param label: The label of this StatisticsPerLabel.
        :type: string_types
        """

        if label is not None:
            if not isinstance(label, string_types):
                raise TypeError("Invalid type for `label`, type has to be `string_types`")

        self._label = label

    @property
    def billable_minutes(self):
        # type: () -> float
        """Gets the billable_minutes of this StatisticsPerLabel.

        The billable minutes.

        :return: The billable_minutes of this StatisticsPerLabel.
        :rtype: float
        """
        return self._billable_minutes

    @billable_minutes.setter
    def billable_minutes(self, billable_minutes):
        # type: (float) -> None
        """Sets the billable_minutes of this StatisticsPerLabel.

        The billable minutes.

        :param billable_minutes: The billable_minutes of this StatisticsPerLabel.
        :type: float
        """

        if billable_minutes is not None:
            if not isinstance(billable_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_minutes`, type has to be `float`")

        self._billable_minutes = billable_minutes

    @property
    def billable_encoding_minutes(self):
        # type: () -> list[BillableEncodingMinutes]
        """Gets the billable_encoding_minutes of this StatisticsPerLabel.

        Billable minutes for each encoding configuration

        :return: The billable_encoding_minutes of this StatisticsPerLabel.
        :rtype: list[BillableEncodingMinutes]
        """
        return self._billable_encoding_minutes

    @billable_encoding_minutes.setter
    def billable_encoding_minutes(self, billable_encoding_minutes):
        # type: (list) -> None
        """Sets the billable_encoding_minutes of this StatisticsPerLabel.

        Billable minutes for each encoding configuration

        :param billable_encoding_minutes: The billable_encoding_minutes of this StatisticsPerLabel.
        :type: list[BillableEncodingMinutes]
        """

        if billable_encoding_minutes is not None:
            if not isinstance(billable_encoding_minutes, list):
                raise TypeError("Invalid type for `billable_encoding_minutes`, type has to be `list[BillableEncodingMinutes]`")

        self._billable_encoding_minutes = billable_encoding_minutes

    @property
    def billable_transmuxing_minutes(self):
        # type: () -> float
        """Gets the billable_transmuxing_minutes of this StatisticsPerLabel.

        Billable minutes for muxings.

        :return: The billable_transmuxing_minutes of this StatisticsPerLabel.
        :rtype: float
        """
        return self._billable_transmuxing_minutes

    @billable_transmuxing_minutes.setter
    def billable_transmuxing_minutes(self, billable_transmuxing_minutes):
        # type: (float) -> None
        """Sets the billable_transmuxing_minutes of this StatisticsPerLabel.

        Billable minutes for muxings.

        :param billable_transmuxing_minutes: The billable_transmuxing_minutes of this StatisticsPerLabel.
        :type: float
        """

        if billable_transmuxing_minutes is not None:
            if not isinstance(billable_transmuxing_minutes, (float, int)):
                raise TypeError("Invalid type for `billable_transmuxing_minutes`, type has to be `float`")

        self._billable_transmuxing_minutes = billable_transmuxing_minutes

    @property
    def billable_feature_minutes(self):
        # type: () -> list[BillableEncodingFeatureMinutes]
        """Gets the billable_feature_minutes of this StatisticsPerLabel.

        Billable minutes for features

        :return: The billable_feature_minutes of this StatisticsPerLabel.
        :rtype: list[BillableEncodingFeatureMinutes]
        """
        return self._billable_feature_minutes

    @billable_feature_minutes.setter
    def billable_feature_minutes(self, billable_feature_minutes):
        # type: (list) -> None
        """Sets the billable_feature_minutes of this StatisticsPerLabel.

        Billable minutes for features

        :param billable_feature_minutes: The billable_feature_minutes of this StatisticsPerLabel.
        :type: list[BillableEncodingFeatureMinutes]
        """

        if billable_feature_minutes is not None:
            if not isinstance(billable_feature_minutes, list):
                raise TypeError("Invalid type for `billable_feature_minutes`, type has to be `list[BillableEncodingFeatureMinutes]`")

        self._billable_feature_minutes = billable_feature_minutes

    @property
    def billable_egress_bytes(self):
        # type: () -> list[EgressInformation]
        """Gets the billable_egress_bytes of this StatisticsPerLabel.

        Billable egress output

        :return: The billable_egress_bytes of this StatisticsPerLabel.
        :rtype: list[EgressInformation]
        """
        return self._billable_egress_bytes

    @billable_egress_bytes.setter
    def billable_egress_bytes(self, billable_egress_bytes):
        # type: (list) -> None
        """Sets the billable_egress_bytes of this StatisticsPerLabel.

        Billable egress output

        :param billable_egress_bytes: The billable_egress_bytes of this StatisticsPerLabel.
        :type: list[EgressInformation]
        """

        if billable_egress_bytes is not None:
            if not isinstance(billable_egress_bytes, list):
                raise TypeError("Invalid type for `billable_egress_bytes`, type has to be `list[EgressInformation]`")

        self._billable_egress_bytes = billable_egress_bytes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(StatisticsPerLabel, self), "to_dict"):
            result = super(StatisticsPerLabel, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticsPerLabel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class AnalyticsInsightsOrganizationSettingsRequest(object):
    @poscheck_model
    def __init__(self,
                 include_in_insights=None):
        # type: (bool) -> None

        self._include_in_insights = None
        self.discriminator = None

        if include_in_insights is not None:
            self.include_in_insights = include_in_insights

    @property
    def openapi_types(self):
        types = {
            'include_in_insights': 'bool'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'include_in_insights': 'includeInInsights'
        }
        return attributes

    @property
    def include_in_insights(self):
        # type: () -> bool
        """Gets the include_in_insights of this AnalyticsInsightsOrganizationSettingsRequest.

        Whether the organization's data is being contributed to industry insights

        :return: The include_in_insights of this AnalyticsInsightsOrganizationSettingsRequest.
        :rtype: bool
        """
        return self._include_in_insights

    @include_in_insights.setter
    def include_in_insights(self, include_in_insights):
        # type: (bool) -> None
        """Sets the include_in_insights of this AnalyticsInsightsOrganizationSettingsRequest.

        Whether the organization's data is being contributed to industry insights

        :param include_in_insights: The include_in_insights of this AnalyticsInsightsOrganizationSettingsRequest.
        :type: bool
        """

        if include_in_insights is not None:
            if not isinstance(include_in_insights, bool):
                raise TypeError("Invalid type for `include_in_insights`, type has to be `bool`")

        self._include_in_insights = include_in_insights

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsInsightsOrganizationSettingsRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.inputs.inputs_api import InputsApi
from bitmovin_api_sdk.encoding.inputs.type.type_api import TypeApi
from bitmovin_api_sdk.encoding.inputs.rtmp.rtmp_api import RtmpApi
from bitmovin_api_sdk.encoding.inputs.redundant_rtmp.redundant_rtmp_api import RedundantRtmpApi
from bitmovin_api_sdk.encoding.inputs.s3.s3_api import S3Api
from bitmovin_api_sdk.encoding.inputs.s3_role_based.s3_role_based_api import S3RoleBasedApi
from bitmovin_api_sdk.encoding.inputs.generic_s3.generic_s3_api import GenericS3Api
from bitmovin_api_sdk.encoding.inputs.local.local_api import LocalApi
from bitmovin_api_sdk.encoding.inputs.gcs.gcs_api import GcsApi
from bitmovin_api_sdk.encoding.inputs.gcs_service_account.gcs_service_account_api import GcsServiceAccountApi
from bitmovin_api_sdk.encoding.inputs.azure.azure_api import AzureApi
from bitmovin_api_sdk.encoding.inputs.ftp.ftp_api import FtpApi
from bitmovin_api_sdk.encoding.inputs.hls.hls_api import HlsApi
from bitmovin_api_sdk.encoding.inputs.sftp.sftp_api import SftpApi
from bitmovin_api_sdk.encoding.inputs.http.http_api import HttpApi
from bitmovin_api_sdk.encoding.inputs.https.https_api import HttpsApi
from bitmovin_api_sdk.encoding.inputs.aspera.aspera_api import AsperaApi
from bitmovin_api_sdk.encoding.inputs.akamai_netstorage.akamai_netstorage_api import AkamaiNetstorageApi
from bitmovin_api_sdk.encoding.inputs.srt.srt_api import SrtApi
from bitmovin_api_sdk.encoding.inputs.zixi.zixi_api import ZixiApi
from bitmovin_api_sdk.encoding.inputs.direct_file_upload.direct_file_upload_api import DirectFileUploadApi
from bitmovin_api_sdk.encoding.inputs.input_list_query_params import InputListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class LiveStandbyPoolEncodingStatus(Enum):
    TO_BE_CREATED = "TO_BE_CREATED"
    CREATING = "CREATING"
    PREPARING = "PREPARING"
    READY = "READY"
    TO_BE_DELETED = "TO_BE_DELETED"
    DELETING = "DELETING"
    ACQUIRED = "ACQUIRED"
    ERROR = "ERROR"



from bitmovin_api_sdk.encoding.live.standby_pools.encodings.encodings_api import EncodingsApi
from bitmovin_api_sdk.encoding.live.standby_pools.encodings.live_standby_pool_encoding_list_query_params import LiveStandbyPoolEncodingListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.dolby_vision_muxing_configuration import DolbyVisionMuxingConfiguration
from bitmovin_api_sdk.models.fragmented_mp4_muxing_manifest_type import FragmentedMp4MuxingManifestType
from bitmovin_api_sdk.models.muxing import Muxing
from bitmovin_api_sdk.models.stream_conditions_mode import StreamConditionsMode
import pprint
import six


class Mp4Muxing(Muxing):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 streams=None,
                 outputs=None,
                 avg_bitrate=None,
                 min_bitrate=None,
                 max_bitrate=None,
                 ignored_by=None,
                 stream_conditions_mode=None,
                 filename=None,
                 fragment_duration=None,
                 minimum_fragment_duration=None,
                 fragmented_mp4_muxing_manifest_type=None,
                 dolby_vision_configuration=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, list[MuxingStream], list[EncodingOutput], int, int, int, list[Ignoring], StreamConditionsMode, string_types, int, float, FragmentedMp4MuxingManifestType, DolbyVisionMuxingConfiguration) -> None
        super(Mp4Muxing, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data, streams=streams, outputs=outputs, avg_bitrate=avg_bitrate, min_bitrate=min_bitrate, max_bitrate=max_bitrate, ignored_by=ignored_by, stream_conditions_mode=stream_conditions_mode)

        self._filename = None
        self._fragment_duration = None
        self._minimum_fragment_duration = None
        self._fragmented_mp4_muxing_manifest_type = None
        self._dolby_vision_configuration = None
        self.discriminator = None

        if filename is not None:
            self.filename = filename
        if fragment_duration is not None:
            self.fragment_duration = fragment_duration
        if minimum_fragment_duration is not None:
            self.minimum_fragment_duration = minimum_fragment_duration
        if fragmented_mp4_muxing_manifest_type is not None:
            self.fragmented_mp4_muxing_manifest_type = fragmented_mp4_muxing_manifest_type
        if dolby_vision_configuration is not None:
            self.dolby_vision_configuration = dolby_vision_configuration

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(Mp4Muxing, self), 'openapi_types'):
            types = getattr(super(Mp4Muxing, self), 'openapi_types')

        types.update({
            'filename': 'string_types',
            'fragment_duration': 'int',
            'minimum_fragment_duration': 'float',
            'fragmented_mp4_muxing_manifest_type': 'FragmentedMp4MuxingManifestType',
            'dolby_vision_configuration': 'DolbyVisionMuxingConfiguration'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(Mp4Muxing, self), 'attribute_map'):
            attributes = getattr(super(Mp4Muxing, self), 'attribute_map')

        attributes.update({
            'filename': 'filename',
            'fragment_duration': 'fragmentDuration',
            'minimum_fragment_duration': 'minimumFragmentDuration',
            'fragmented_mp4_muxing_manifest_type': 'fragmentedMP4MuxingManifestType',
            'dolby_vision_configuration': 'dolbyVisionConfiguration'
        })
        return attributes

    @property
    def filename(self):
        # type: () -> string_types
        """Gets the filename of this Mp4Muxing.

        Name of the output file (either `filename` or `name` is required, prefer `filename`)

        :return: The filename of this Mp4Muxing.
        :rtype: string_types
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        # type: (string_types) -> None
        """Sets the filename of this Mp4Muxing.

        Name of the output file (either `filename` or `name` is required, prefer `filename`)

        :param filename: The filename of this Mp4Muxing.
        :type: string_types
        """

        if filename is not None:
            if not isinstance(filename, string_types):
                raise TypeError("Invalid type for `filename`, type has to be `string_types`")

        self._filename = filename

    @property
    def fragment_duration(self):
        # type: () -> int
        """Gets the fragment_duration of this Mp4Muxing.

         Duration of fragments in milliseconds. Required for Fragmented MP4 Muxing (for Smooth Streaming or DASH On-Demand). Not setting this will result in unfragmented mp4.

        :return: The fragment_duration of this Mp4Muxing.
        :rtype: int
        """
        return self._fragment_duration

    @fragment_duration.setter
    def fragment_duration(self, fragment_duration):
        # type: (int) -> None
        """Sets the fragment_duration of this Mp4Muxing.

         Duration of fragments in milliseconds. Required for Fragmented MP4 Muxing (for Smooth Streaming or DASH On-Demand). Not setting this will result in unfragmented mp4.

        :param fragment_duration: The fragment_duration of this Mp4Muxing.
        :type: int
        """

        if fragment_duration is not None:
            if not isinstance(fragment_duration, int):
                raise TypeError("Invalid type for `fragment_duration`, type has to be `int`")

        self._fragment_duration = fragment_duration

    @property
    def minimum_fragment_duration(self):
        # type: () -> float
        """Gets the minimum_fragment_duration of this Mp4Muxing.

        Prevents creation of very short fragments (in seconds). If the last fragment is shorter than minimumFragmentDuration or there is a custom keyframe too close to a fragment boundary, short fragments will be omitted by removing fragment boundaries, resulting in a fragment of a size up to fragmentDuration + minimumFragmentDuration.

        :return: The minimum_fragment_duration of this Mp4Muxing.
        :rtype: float
        """
        return self._minimum_fragment_duration

    @minimum_fragment_duration.setter
    def minimum_fragment_duration(self, minimum_fragment_duration):
        # type: (float) -> None
        """Sets the minimum_fragment_duration of this Mp4Muxing.

        Prevents creation of very short fragments (in seconds). If the last fragment is shorter than minimumFragmentDuration or there is a custom keyframe too close to a fragment boundary, short fragments will be omitted by removing fragment boundaries, resulting in a fragment of a size up to fragmentDuration + minimumFragmentDuration.

        :param minimum_fragment_duration: The minimum_fragment_duration of this Mp4Muxing.
        :type: float
        """

        if minimum_fragment_duration is not None:
            if not isinstance(minimum_fragment_duration, (float, int)):
                raise TypeError("Invalid type for `minimum_fragment_duration`, type has to be `float`")

        self._minimum_fragment_duration = minimum_fragment_duration

    @property
    def fragmented_mp4_muxing_manifest_type(self):
        # type: () -> FragmentedMp4MuxingManifestType
        """Gets the fragmented_mp4_muxing_manifest_type of this Mp4Muxing.


        :return: The fragmented_mp4_muxing_manifest_type of this Mp4Muxing.
        :rtype: FragmentedMp4MuxingManifestType
        """
        return self._fragmented_mp4_muxing_manifest_type

    @fragmented_mp4_muxing_manifest_type.setter
    def fragmented_mp4_muxing_manifest_type(self, fragmented_mp4_muxing_manifest_type):
        # type: (FragmentedMp4MuxingManifestType) -> None
        """Sets the fragmented_mp4_muxing_manifest_type of this Mp4Muxing.


        :param fragmented_mp4_muxing_manifest_type: The fragmented_mp4_muxing_manifest_type of this Mp4Muxing.
        :type: FragmentedMp4MuxingManifestType
        """

        if fragmented_mp4_muxing_manifest_type is not None:
            if not isinstance(fragmented_mp4_muxing_manifest_type, FragmentedMp4MuxingManifestType):
                raise TypeError("Invalid type for `fragmented_mp4_muxing_manifest_type`, type has to be `FragmentedMp4MuxingManifestType`")

        self._fragmented_mp4_muxing_manifest_type = fragmented_mp4_muxing_manifest_type

    @property
    def dolby_vision_configuration(self):
        # type: () -> DolbyVisionMuxingConfiguration
        """Gets the dolby_vision_configuration of this Mp4Muxing.

        Dolby Vision specific configuration

        :return: The dolby_vision_configuration of this Mp4Muxing.
        :rtype: DolbyVisionMuxingConfiguration
        """
        return self._dolby_vision_configuration

    @dolby_vision_configuration.setter
    def dolby_vision_configuration(self, dolby_vision_configuration):
        # type: (DolbyVisionMuxingConfiguration) -> None
        """Sets the dolby_vision_configuration of this Mp4Muxing.

        Dolby Vision specific configuration

        :param dolby_vision_configuration: The dolby_vision_configuration of this Mp4Muxing.
        :type: DolbyVisionMuxingConfiguration
        """

        if dolby_vision_configuration is not None:
            if not isinstance(dolby_vision_configuration, DolbyVisionMuxingConfiguration):
                raise TypeError("Invalid type for `dolby_vision_configuration`, type has to be `DolbyVisionMuxingConfiguration`")

        self._dolby_vision_configuration = dolby_vision_configuration

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(Mp4Muxing, self), "to_dict"):
            result = super(Mp4Muxing, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Mp4Muxing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from datetime import datetime
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.prewarmed_encoder_pool_action import PrewarmedEncoderPoolAction
import pprint
import six


class PrewarmedEncoderPoolSchedule(BitmovinResponse):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 action=None,
                 trigger_date=None):
        # type: (string_types, PrewarmedEncoderPoolAction, datetime) -> None
        super(PrewarmedEncoderPoolSchedule, self).__init__(id_=id_)

        self._action = None
        self._trigger_date = None
        self.discriminator = None

        if action is not None:
            self.action = action
        if trigger_date is not None:
            self.trigger_date = trigger_date

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(PrewarmedEncoderPoolSchedule, self), 'openapi_types'):
            types = getattr(super(PrewarmedEncoderPoolSchedule, self), 'openapi_types')

        types.update({
            'action': 'PrewarmedEncoderPoolAction',
            'trigger_date': 'datetime'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(PrewarmedEncoderPoolSchedule, self), 'attribute_map'):
            attributes = getattr(super(PrewarmedEncoderPoolSchedule, self), 'attribute_map')

        attributes.update({
            'action': 'action',
            'trigger_date': 'triggerDate'
        })
        return attributes

    @property
    def action(self):
        # type: () -> PrewarmedEncoderPoolAction
        """Gets the action of this PrewarmedEncoderPoolSchedule.

        The action to be triggered by the schedule (start or stop) (required)

        :return: The action of this PrewarmedEncoderPoolSchedule.
        :rtype: PrewarmedEncoderPoolAction
        """
        return self._action

    @action.setter
    def action(self, action):
        # type: (PrewarmedEncoderPoolAction) -> None
        """Sets the action of this PrewarmedEncoderPoolSchedule.

        The action to be triggered by the schedule (start or stop) (required)

        :param action: The action of this PrewarmedEncoderPoolSchedule.
        :type: PrewarmedEncoderPoolAction
        """

        if action is not None:
            if not isinstance(action, PrewarmedEncoderPoolAction):
                raise TypeError("Invalid type for `action`, type has to be `PrewarmedEncoderPoolAction`")

        self._action = action

    @property
    def trigger_date(self):
        # type: () -> datetime
        """Gets the trigger_date of this PrewarmedEncoderPoolSchedule.

        An instant in the future when the specified action should be triggered. Given as UTC expressed in ISO 8601 format (\"YYYY-MM-DDThh:mm:ssZ\"). Seconds will be ignored. (required)

        :return: The trigger_date of this PrewarmedEncoderPoolSchedule.
        :rtype: datetime
        """
        return self._trigger_date

    @trigger_date.setter
    def trigger_date(self, trigger_date):
        # type: (datetime) -> None
        """Sets the trigger_date of this PrewarmedEncoderPoolSchedule.

        An instant in the future when the specified action should be triggered. Given as UTC expressed in ISO 8601 format (\"YYYY-MM-DDThh:mm:ssZ\"). Seconds will be ignored. (required)

        :param trigger_date: The trigger_date of this PrewarmedEncoderPoolSchedule.
        :type: datetime
        """

        if trigger_date is not None:
            if not isinstance(trigger_date, datetime):
                raise TypeError("Invalid type for `trigger_date`, type has to be `datetime`")

        self._trigger_date = trigger_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(PrewarmedEncoderPoolSchedule, self), "to_dict"):
            result = super(PrewarmedEncoderPoolSchedule, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PrewarmedEncoderPoolSchedule):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.encoding_template_details import EncodingTemplateDetails
from bitmovin_api_sdk.models.encoding_template_request import EncodingTemplateRequest
from bitmovin_api_sdk.models.encoding_template_response import EncodingTemplateResponse
from bitmovin_api_sdk.models.encoding_template_start_response import EncodingTemplateStartResponse
from bitmovin_api_sdk.models.encoding_template_type import EncodingTemplateType
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.templates.encoding_template_response_list_query_params import EncodingTemplateResponseListQueryParams


class TemplatesApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(TemplatesApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_template_request, **kwargs):
        # type: (object, dict) -> EncodingTemplateDetails
        """Store an Encoding Template

        :param encoding_template_request: The Encoding Template to be stored
        :type encoding_template_request: EncodingTemplateRequest, required
        :return: Stored Encoding Template info
        :rtype: EncodingTemplateDetails
        """

        return self.api_client.post(
            '/encoding/templates',
            encoding_template_request,
            type=EncodingTemplateDetails,
            **kwargs
        )

    def delete(self, encoding_template_id, **kwargs):
        # type: (string_types, dict) -> BitmovinResponse
        """Delete Encoding Template

        :param encoding_template_id: Id of the encoding template to delete
        :type encoding_template_id: string_types, required
        :return: Id of the deleted Encoding Template
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/templates/{encoding_template_id}',
            path_params={'encoding_template_id': encoding_template_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_template_id, **kwargs):
        # type: (string_types, dict) -> EncodingTemplateDetails
        """Encoding Template details

        :param encoding_template_id: Id of the Encoding Template
        :type encoding_template_id: string_types, required
        :return: Encoding Template details
        :rtype: EncodingTemplateDetails
        """

        return self.api_client.get(
            '/encoding/templates/{encoding_template_id}',
            path_params={'encoding_template_id': encoding_template_id},
            type=EncodingTemplateDetails,
            **kwargs
        )

    def list(self, query_params=None, **kwargs):
        # type: (EncodingTemplateResponseListQueryParams, dict) -> EncodingTemplateResponse
        """List stored Encoding Templates

        :param query_params: Query parameters
        :type query_params: EncodingTemplateResponseListQueryParams
        :return: A list of the stored encoding templates
        :rtype: EncodingTemplateResponse
        """

        return self.api_client.get(
            '/encoding/templates',
            query_params=query_params,
            pagination_response=True,
            type=EncodingTemplateResponse,
            **kwargs
        )

    def start(self, encoding_template_request, **kwargs):
        # type: (object, dict) -> EncodingTemplateStartResponse
        """Start an Encoding defined with an Encoding Template

        :param encoding_template_request: The Encoding Template to start an Encoding from
        :type encoding_template_request: EncodingTemplateRequest, required
        :return:
        :rtype: EncodingTemplateStartResponse
        """

        return self.api_client.post(
            '/encoding/templates/start',
            encoding_template_request,
            type=EncodingTemplateStartResponse,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class HlsTargetDurationRoundingMode(Enum):
    UPWARD_ROUNDING = "UPWARD_ROUNDING"
    NORMAL_ROUNDING = "NORMAL_ROUNDING"



from bitmovin_api_sdk.encoding.encodings.transfer_retries.transfer_retries_api import TransferRetriesApi
from bitmovin_api_sdk.encoding.encodings.transfer_retries.transfer_retry_list_query_params import TransferRetryListQueryParams



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class EnhancedDeinterlaceMode(Enum):
    FRAME = "FRAME"
    FIELD = "FIELD"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class TransferVersion(Enum):
    DEFAULT = "DEFAULT"
    POOL = "POOL"



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
import pprint
import six


class Statistics(object):
    @poscheck_model
    def __init__(self,
                 bytes_encoded_total=None,
                 time_encoded_total=None,
                 bytes_egress_total=None):
        # type: (int, int, int) -> None

        self._bytes_encoded_total = None
        self._time_encoded_total = None
        self._bytes_egress_total = None
        self.discriminator = None

        if bytes_encoded_total is not None:
            self.bytes_encoded_total = bytes_encoded_total
        if time_encoded_total is not None:
            self.time_encoded_total = time_encoded_total
        if bytes_egress_total is not None:
            self.bytes_egress_total = bytes_egress_total

    @property
    def openapi_types(self):
        types = {
            'bytes_encoded_total': 'int',
            'time_encoded_total': 'int',
            'bytes_egress_total': 'int'
        }

        return types

    @property
    def attribute_map(self):
        attributes = {
            'bytes_encoded_total': 'bytesEncodedTotal',
            'time_encoded_total': 'timeEncodedTotal',
            'bytes_egress_total': 'bytesEgressTotal'
        }
        return attributes

    @property
    def bytes_encoded_total(self):
        # type: () -> int
        """Gets the bytes_encoded_total of this Statistics.

        Bytes encoded total. (required)

        :return: The bytes_encoded_total of this Statistics.
        :rtype: int
        """
        return self._bytes_encoded_total

    @bytes_encoded_total.setter
    def bytes_encoded_total(self, bytes_encoded_total):
        # type: (int) -> None
        """Sets the bytes_encoded_total of this Statistics.

        Bytes encoded total. (required)

        :param bytes_encoded_total: The bytes_encoded_total of this Statistics.
        :type: int
        """

        if bytes_encoded_total is not None:
            if not isinstance(bytes_encoded_total, int):
                raise TypeError("Invalid type for `bytes_encoded_total`, type has to be `int`")

        self._bytes_encoded_total = bytes_encoded_total

    @property
    def time_encoded_total(self):
        # type: () -> int
        """Gets the time_encoded_total of this Statistics.

        Time in seconds encoded for all contained daily statistics. (required)

        :return: The time_encoded_total of this Statistics.
        :rtype: int
        """
        return self._time_encoded_total

    @time_encoded_total.setter
    def time_encoded_total(self, time_encoded_total):
        # type: (int) -> None
        """Sets the time_encoded_total of this Statistics.

        Time in seconds encoded for all contained daily statistics. (required)

        :param time_encoded_total: The time_encoded_total of this Statistics.
        :type: int
        """

        if time_encoded_total is not None:
            if not isinstance(time_encoded_total, int):
                raise TypeError("Invalid type for `time_encoded_total`, type has to be `int`")

        self._time_encoded_total = time_encoded_total

    @property
    def bytes_egress_total(self):
        # type: () -> int
        """Gets the bytes_egress_total of this Statistics.

        Egress output generated by file transfers in bytes

        :return: The bytes_egress_total of this Statistics.
        :rtype: int
        """
        return self._bytes_egress_total

    @bytes_egress_total.setter
    def bytes_egress_total(self, bytes_egress_total):
        # type: (int) -> None
        """Sets the bytes_egress_total of this Statistics.

        Egress output generated by file transfers in bytes

        :param bytes_egress_total: The bytes_egress_total of this Statistics.
        :type: int
        """

        if bytes_egress_total is not None:
            if not isinstance(bytes_egress_total, int):
                raise TypeError("Invalid type for `bytes_egress_total`, type has to be `int`")

        self._bytes_egress_total = bytes_egress_total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Statistics):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.webvtt_api import WebvttApi
from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.customdata.customdata_api import CustomdataApi
from bitmovin_api_sdk.encoding.configurations.subtitles.webvtt.web_vtt_configuration_list_query_params import WebVttConfigurationListQueryParams



# coding: utf-8

from __future__ import absolute_import

from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
from bitmovin_api_sdk.common.poscheck import poscheck_except
from bitmovin_api_sdk.models.bitmovin_response import BitmovinResponse
from bitmovin_api_sdk.models.dolby_vision_input_stream import DolbyVisionInputStream
from bitmovin_api_sdk.models.response_envelope import ResponseEnvelope
from bitmovin_api_sdk.models.response_error import ResponseError
from bitmovin_api_sdk.encoding.encodings.input_streams.dolby_vision.dolby_vision_input_stream_list_query_params import DolbyVisionInputStreamListQueryParams


class DolbyVisionApi(BaseApi):
    @poscheck_except(2)
    def __init__(self, api_key, tenant_org_id=None, base_url=None, logger=None):
        # type: (str, str, str, BitmovinApiLoggerBase) -> None

        super(DolbyVisionApi, self).__init__(
            api_key=api_key,
            tenant_org_id=tenant_org_id,
            base_url=base_url,
            logger=logger
        )

    def create(self, encoding_id, dolby_vision_input_stream, **kwargs):
        # type: (string_types, DolbyVisionInputStream, dict) -> DolbyVisionInputStream
        """Add Dolby Vision input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param dolby_vision_input_stream: The Dolby Vision input stream to be created
        :type dolby_vision_input_stream: DolbyVisionInputStream, required
        :return: Dolby Vision input stream
        :rtype: DolbyVisionInputStream
        """

        return self.api_client.post(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-vision',
            dolby_vision_input_stream,
            path_params={'encoding_id': encoding_id},
            type=DolbyVisionInputStream,
            **kwargs
        )

    def delete(self, encoding_id, dolby_vision_input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> BitmovinResponse
        """Delete Dolby Vision input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param dolby_vision_input_stream_id: Id of the Dolby Vision input stream.
        :type dolby_vision_input_stream_id: string_types, required
        :return: Id of the Dolby Vision input stream
        :rtype: BitmovinResponse
        """

        return self.api_client.delete(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-vision/{dolby_vision_input_stream_id}',
            path_params={'encoding_id': encoding_id, 'dolby_vision_input_stream_id': dolby_vision_input_stream_id},
            type=BitmovinResponse,
            **kwargs
        )

    def get(self, encoding_id, dolby_vision_input_stream_id, **kwargs):
        # type: (string_types, string_types, dict) -> DolbyVisionInputStream
        """Dolby Vision input stream details

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param dolby_vision_input_stream_id: Id of the Dolby Vision input stream.
        :type dolby_vision_input_stream_id: string_types, required
        :return: Dolby Vision input stream
        :rtype: DolbyVisionInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-vision/{dolby_vision_input_stream_id}',
            path_params={'encoding_id': encoding_id, 'dolby_vision_input_stream_id': dolby_vision_input_stream_id},
            type=DolbyVisionInputStream,
            **kwargs
        )

    def list(self, encoding_id, query_params=None, **kwargs):
        # type: (string_types, DolbyVisionInputStreamListQueryParams, dict) -> DolbyVisionInputStream
        """List Dolby Vision input stream

        :param encoding_id: Id of the encoding.
        :type encoding_id: string_types, required
        :param query_params: Query parameters
        :type query_params: DolbyVisionInputStreamListQueryParams
        :return: List of Dolby Vision input stream
        :rtype: DolbyVisionInputStream
        """

        return self.api_client.get(
            '/encoding/encodings/{encoding_id}/input-streams/dolby-vision',
            path_params={'encoding_id': encoding_id},
            query_params=query_params,
            pagination_response=True,
            type=DolbyVisionInputStream,
            **kwargs
        )



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model
from bitmovin_api_sdk.models.bitmovin_resource import BitmovinResource
from bitmovin_api_sdk.models.caption_character_encoding import CaptionCharacterEncoding
from bitmovin_api_sdk.models.input_path import InputPath
import pprint
import six


class BurnInSubtitleSrt(BitmovinResource):
    @poscheck_model
    def __init__(self,
                 id_=None,
                 name=None,
                 description=None,
                 created_at=None,
                 modified_at=None,
                 custom_data=None,
                 character_encoding=None,
                 input_=None):
        # type: (string_types, string_types, string_types, datetime, datetime, dict, CaptionCharacterEncoding, InputPath) -> None
        super(BurnInSubtitleSrt, self).__init__(id_=id_, name=name, description=description, created_at=created_at, modified_at=modified_at, custom_data=custom_data)

        self._character_encoding = None
        self._input = None
        self.discriminator = None

        if character_encoding is not None:
            self.character_encoding = character_encoding
        if input_ is not None:
            self.input = input_

    @property
    def openapi_types(self):
        types = {}

        if hasattr(super(BurnInSubtitleSrt, self), 'openapi_types'):
            types = getattr(super(BurnInSubtitleSrt, self), 'openapi_types')

        types.update({
            'character_encoding': 'CaptionCharacterEncoding',
            'input': 'InputPath'
        })

        return types

    @property
    def attribute_map(self):
        attributes = {}

        if hasattr(super(BurnInSubtitleSrt, self), 'attribute_map'):
            attributes = getattr(super(BurnInSubtitleSrt, self), 'attribute_map')

        attributes.update({
            'character_encoding': 'characterEncoding',
            'input': 'input'
        })
        return attributes

    @property
    def character_encoding(self):
        # type: () -> CaptionCharacterEncoding
        """Gets the character_encoding of this BurnInSubtitleSrt.

        Character encoding of the SRT file (required)

        :return: The character_encoding of this BurnInSubtitleSrt.
        :rtype: CaptionCharacterEncoding
        """
        return self._character_encoding

    @character_encoding.setter
    def character_encoding(self, character_encoding):
        # type: (CaptionCharacterEncoding) -> None
        """Sets the character_encoding of this BurnInSubtitleSrt.

        Character encoding of the SRT file (required)

        :param character_encoding: The character_encoding of this BurnInSubtitleSrt.
        :type: CaptionCharacterEncoding
        """

        if character_encoding is not None:
            if not isinstance(character_encoding, CaptionCharacterEncoding):
                raise TypeError("Invalid type for `character_encoding`, type has to be `CaptionCharacterEncoding`")

        self._character_encoding = character_encoding

    @property
    def input(self):
        # type: () -> InputPath
        """Gets the input of this BurnInSubtitleSrt.

        The input location to get the SRT file from (required)

        :return: The input of this BurnInSubtitleSrt.
        :rtype: InputPath
        """
        return self._input

    @input.setter
    def input(self, input_):
        # type: (InputPath) -> None
        """Sets the input of this BurnInSubtitleSrt.

        The input location to get the SRT file from (required)

        :param input_: The input of this BurnInSubtitleSrt.
        :type: InputPath
        """

        if input_ is not None:
            if not isinstance(input_, InputPath):
                raise TypeError("Invalid type for `input`, type has to be `InputPath`")

        self._input = input_

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        if hasattr(super(BurnInSubtitleSrt, self), "to_dict"):
            result = super(BurnInSubtitleSrt, self).to_dict()
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if value is None:
                continue
            if isinstance(value, list):
                if len(value) == 0:
                    continue
                result[self.attribute_map.get(attr)] = [y.value if isinstance(y, Enum) else y for y in [x.to_dict() if hasattr(x, "to_dict") else x for x in value]]
            elif hasattr(value, "to_dict"):
                result[self.attribute_map.get(attr)] = value.to_dict()
            elif isinstance(value, Enum):
                result[self.attribute_map.get(attr)] = value.value
            elif isinstance(value, dict):
                result[self.attribute_map.get(attr)] = {k: (v.to_dict() if hasattr(v, "to_dict") else v) for (k, v) in value.items()}
            else:
                result[self.attribute_map.get(attr)] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BurnInSubtitleSrt):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

from enum import Enum
from six import string_types, iteritems
from bitmovin_api_sdk.common.poscheck import poscheck_model


class AnalyticsHttpRequestType(Enum):
    DRM_LICENSE_WIDEVINE_ = "DRM_LICENSE_WIDEVINE,"
    MEDIA_THUMBNAILS_ = "MEDIA_THUMBNAILS,"
    MEDIA_VIDEO_ = "MEDIA_VIDEO,"
    MEDIA_AUDIO_ = "MEDIA_AUDIO,"
    MEDIA_PROGRESSIVE_ = "MEDIA_PROGRESSIVE,"
    MEDIA_SUBTITLES_ = "MEDIA_SUBTITLES,"
    MANIFEST_DASH_ = "MANIFEST_DASH,"
    MANIFEST_HLS_MASTER_ = "MANIFEST_HLS_MASTER,"
    MANIFEST_HLS_VARIANT_ = "MANIFEST_HLS_VARIANT,"
    MANIFEST_SMOOTH_ = "MANIFEST_SMOOTH,"
    KEY_HLS_AES_ = "KEY_HLS_AES,"
    UNKNOWN = "UNKNOWN"
